@@ -1,20 +1,20 @@
-/*
- *
- * Copyright 2016 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2016 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #include <grpc/support/port_platform.h>
 
@@ -46,6 +46,7 @@
 #include "src/core/ext/transport/chttp2/transport/bin_encoder.h"
 #include "src/core/ext/transport/cronet/transport/cronet_status.h"
 #include "src/core/lib/debug/trace.h"
+#include "src/core/lib/gprpp/crash.h"
 #include "src/core/lib/gprpp/debug_location.h"
 #include "src/core/lib/gprpp/status_helper.h"
 #include "src/core/lib/iomgr/closure.h"
@@ -95,7 +96,7 @@ enum e_op_id {
   OP_NUM_OPS
 };
 
-/* Cronet callbacks. See cronet_c_for_grpc.h for documentation for each. */
+// Cronet callbacks. See cronet_c_for_grpc.h for documentation for each.
 
 static void on_stream_ready(bidirectional_stream*);
 static void on_response_headers_received(
@@ -118,22 +119,22 @@ static bidirectional_stream_callback cronet_callbacks = {
     on_failed,
     on_canceled};
 
-/* Cronet transport object */
+// Cronet transport object
 struct grpc_cronet_transport {
-  grpc_transport base; /* must be first element in this structure */
+  grpc_transport base;  // must be first element in this structure
   stream_engine* engine;
   char* host;
   bool use_packet_coalescing;
 };
 typedef struct grpc_cronet_transport grpc_cronet_transport;
 
-/* TODO (makdharma): reorder structure for memory efficiency per
-   http://www.catb.org/esr/structure-packing/#_structure_reordering: */
+// TODO (makdharma): reorder structure for memory efficiency per
+// http://www.catb.org/esr/structure-packing/#_structure_reordering:
 struct read_state {
   explicit read_state(grpc_core::Arena* arena)
       : trailing_metadata(arena), initial_metadata(arena) {}
 
-  /* vars to store data coming from server */
+  // vars to store data coming from server
   char* read_buffer = nullptr;
   bool length_field_received = false;
   int received_bytes = 0;
@@ -144,14 +145,14 @@ struct read_state {
   char* payload_field = nullptr;
   bool read_stream_closed = false;
 
-  /* vars for holding data destined for the application */
+  // vars for holding data destined for the application
   grpc_core::SliceBuffer read_slice_buffer;
 
-  /* vars for trailing metadata */
+  // vars for trailing metadata
   grpc_metadata_batch trailing_metadata;
   bool trailing_metadata_valid = false;
 
-  /* vars for initial metadata */
+  // vars for initial metadata
   grpc_metadata_batch initial_metadata;
 };
 
@@ -159,26 +160,26 @@ struct write_state {
   char* write_buffer = nullptr;
 };
 
-/* track state of one stream op */
+// track state of one stream op
 struct op_state {
   explicit op_state(grpc_core::Arena* arena) : rs(arena) {}
 
   bool state_op_done[OP_NUM_OPS] = {};
   bool state_callback_received[OP_NUM_OPS] = {};
-  /* A non-zero gRPC status code has been seen */
+  // A non-zero gRPC status code has been seen
   bool fail_state = false;
-  /* Transport is discarding all buffered messages */
+  // Transport is discarding all buffered messages
   bool flush_read = false;
   bool flush_cronet_when_ready = false;
   bool pending_write_for_trailer = false;
   bool pending_send_message = false;
-  /* User requested RECV_TRAILING_METADATA */
+  // User requested RECV_TRAILING_METADATA
   bool pending_recv_trailing_metadata = false;
   cronet_net_error_code net_error = OK;
   grpc_error_handle cancel_error;
-  /* data structure for storing data coming from server */
+  // data structure for storing data coming from server
   struct read_state rs;
-  /* data structure for storing data going to the server */
+  // data structure for storing data going to the server
   struct write_state ws;
 };
 
@@ -190,8 +191,8 @@ struct op_and_state {
   grpc_transport_stream_op_batch op;
   struct op_state state;
   bool done = false;
-  struct stream_obj* s; /* Pointer back to the stream object */
-  /* next op_and_state in the linked list */
+  struct stream_obj* s;  // Pointer back to the stream object
+  // next op_and_state in the linked list
   struct op_and_state* next = nullptr;
 };
 
@@ -214,17 +215,17 @@ struct stream_obj {
   bidirectional_stream_header_array header_array =
       bidirectional_stream_header_array();  // Zero-initialize the structure.
 
-  /* Stream level state. Some state will be tracked both at stream and stream_op
-   * level */
+  // Stream level state. Some state will be tracked both at stream and stream_op
+  // level
   struct op_state state;
 
-  /* OP storage */
+  // OP storage
   struct op_storage storage;
 
-  /* Mutex to protect storage */
+  // Mutex to protect storage
   gpr_mu mu;
 
-  /* Refcount object of the stream */
+  // Refcount object of the stream
   grpc_stream_refcount* refcount;
 };
 
@@ -249,9 +250,9 @@ void grpc_cronet_stream_unref(stream_obj* s) { grpc_stream_unref(s->refcount); }
 
 static enum e_op_result execute_stream_op(struct op_and_state* oas);
 
-/*
-  Utility function to translate enum into string for printing
-*/
+//
+// Utility function to translate enum into string for printing
+//
 static const char* op_result_string(enum e_op_result i) {
   switch (i) {
     case ACTION_TAKEN_WITH_CALLBACK:
@@ -330,14 +331,14 @@ inline op_and_state::op_and_state(stream_obj* s,
                                   const grpc_transport_stream_op_batch& op)
     : op(op), state(s->arena), s(s) {}
 
-/*
-  Add a new stream op to op storage.
-*/
+//
+// Add a new stream op to op storage.
+//
 static void add_to_storage(struct stream_obj* s,
                            grpc_transport_stream_op_batch* op) {
   struct op_storage* storage = &s->storage;
-  /* add new op at the beginning of the linked list. The memory is freed
-  in remove_from_storage */
+  // add new op at the beginning of the linked list. The memory is freed
+  // in remove_from_storage
   op_and_state* new_op = new op_and_state(s, *op);
   gpr_mu_lock(&s->mu);
   new_op->next = storage->head;
@@ -354,9 +355,9 @@ static void add_to_storage(struct stream_obj* s,
   gpr_mu_unlock(&s->mu);
 }
 
-/*
-  Traverse the linked list and delete op and free memory
-*/
+//
+// Traverse the linked list and delete op and free memory
+//
 static void remove_from_storage(struct stream_obj* s,
                                 struct op_and_state* oas) {
   struct op_and_state* curr;
@@ -385,12 +386,12 @@ static void remove_from_storage(struct stream_obj* s,
   }
 }
 
-/*
-  Cycle through ops and try to take next action. Break when either
-  an action with callback is taken, or no action is possible.
-  This can get executed from the Cronet network thread via cronet callback
-  or on the application supplied thread via the perform_stream_op function.
-*/
+//
+// Cycle through ops and try to take next action. Break when either
+// an action with callback is taken, or no action is possible.
+// This can get executed from the Cronet network thread via cronet callback
+// or on the application supplied thread via the perform_stream_op function.
+//
 static void execute_from_storage(stream_obj* s) {
   gpr_mu_lock(&s->mu);
   for (struct op_and_state* curr = s->storage.head; curr != nullptr;) {
@@ -399,7 +400,7 @@ static void execute_from_storage(stream_obj* s) {
     enum e_op_result result = execute_stream_op(curr);
     CRONET_LOG(GPR_DEBUG, "execute_stream_op[%p] returns %s", curr,
                op_result_string(result));
-    /* if this op is done, then remove it and free memory */
+    // if this op is done, then remove it and free memory
     if (curr->done) {
       struct op_and_state* next = curr->next;
       remove_from_storage(s, curr);
@@ -407,9 +408,9 @@ static void execute_from_storage(stream_obj* s) {
     } else if (result == NO_ACTION_POSSIBLE) {
       curr = curr->next;
     } else if (result == ACTION_TAKEN_WITH_CALLBACK) {
-      /* wait for the callback */
+      // wait for the callback
       break;
-    } /* continue processing the same op if ACTION_TAKEN_WITHOUT_CALLBACK */
+    }  // continue processing the same op if ACTION_TAKEN_WITHOUT_CALLBACK
   }
   gpr_mu_unlock(&s->mu);
 }
@@ -439,9 +440,9 @@ static void convert_cronet_array_to_metadata(
   }
 }
 
-/*
-  Cronet callback
-*/
+//
+// Cronet callback
+//
 static void on_failed(bidirectional_stream* stream, int net_error) {
   gpr_log(GPR_ERROR, "on_failed(%p, %d)", stream, net_error);
   grpc_core::ApplicationCallbackExecCtx callback_exec_ctx;
@@ -467,9 +468,9 @@ static void on_failed(bidirectional_stream* stream, int net_error) {
   GRPC_CRONET_STREAM_UNREF(s, "cronet transport");
 }
 
-/*
-  Cronet callback
-*/
+//
+// Cronet callback
+//
 static void on_canceled(bidirectional_stream* stream) {
   CRONET_LOG(GPR_DEBUG, "on_canceled(%p)", stream);
   grpc_core::ApplicationCallbackExecCtx callback_exec_ctx;
@@ -494,9 +495,9 @@ static void on_canceled(bidirectional_stream* stream) {
   GRPC_CRONET_STREAM_UNREF(s, "cronet transport");
 }
 
-/*
-  Cronet callback
-*/
+//
+// Cronet callback
+//
 static void on_succeeded(bidirectional_stream* stream) {
   CRONET_LOG(GPR_DEBUG, "on_succeeded(%p)", stream);
   grpc_core::ApplicationCallbackExecCtx callback_exec_ctx;
@@ -513,9 +514,9 @@ static void on_succeeded(bidirectional_stream* stream) {
   GRPC_CRONET_STREAM_UNREF(s, "cronet transport");
 }
 
-/*
-  Cronet callback
-*/
+//
+// Cronet callback
+//
 static void on_stream_ready(bidirectional_stream* stream) {
   CRONET_LOG(GPR_DEBUG, "W: on_stream_ready(%p)", stream);
   grpc_core::ApplicationCallbackExecCtx callback_exec_ctx;
@@ -525,13 +526,13 @@ static void on_stream_ready(bidirectional_stream* stream) {
   gpr_mu_lock(&s->mu);
   s->state.state_op_done[OP_SEND_INITIAL_METADATA] = true;
   s->state.state_callback_received[OP_SEND_INITIAL_METADATA] = true;
-  /* Free the memory allocated for headers */
+  // Free the memory allocated for headers
   if (s->header_array.headers) {
     gpr_free(s->header_array.headers);
     s->header_array.headers = nullptr;
   }
-  /* Send the initial metadata on wire if there is no SEND_MESSAGE or
-   * SEND_TRAILING_METADATA ops pending */
+  // Send the initial metadata on wire if there is no SEND_MESSAGE or
+  // SEND_TRAILING_METADATA ops pending
   if (t->use_packet_coalescing) {
     if (s->state.flush_cronet_when_ready) {
       CRONET_LOG(GPR_DEBUG, "cronet_bidirectional_stream_flush (%p)", s->cbs);
@@ -542,9 +543,9 @@ static void on_stream_ready(bidirectional_stream* stream) {
   execute_from_storage(s);
 }
 
-/*
-  Cronet callback
-*/
+//
+// Cronet callback
+//
 static void on_response_headers_received(
     bidirectional_stream* stream,
     const bidirectional_stream_header_array* headers,
@@ -555,14 +556,14 @@ static void on_response_headers_received(
              headers, negotiated_protocol);
   stream_obj* s = static_cast<stream_obj*>(stream->annotation);
 
-  /* Identify if this is a header or a trailer (in a trailer-only response case)
-   */
+  // Identify if this is a header or a trailer (in a trailer-only response case)
+  //
   for (size_t i = 0; i < headers->count; i++) {
     if (0 == strcmp("grpc-status", headers->headers[i].key)) {
       on_response_trailers_received(stream, headers);
 
-      /* Do an extra read for a trailer-only stream to trigger on_succeeded()
-       * callback */
+      // Do an extra read for a trailer-only stream to trigger on_succeeded()
+      // callback
       read_grpc_header(s);
       return;
     }
@@ -573,8 +574,8 @@ static void on_response_headers_received(
   s->state.state_callback_received[OP_RECV_INITIAL_METADATA] = true;
   if (!(s->state.state_op_done[OP_CANCEL_ERROR] ||
         s->state.state_callback_received[OP_FAILED])) {
-    /* Do an extra read to trigger on_succeeded() callback in case connection
-     is closed */
+    // Do an extra read to trigger on_succeeded() callback in case connection
+    // is closed
     GPR_ASSERT(s->state.rs.length_field_received == false);
     read_grpc_header(s);
   }
@@ -582,9 +583,9 @@ static void on_response_headers_received(
   execute_from_storage(s);
 }
 
-/*
-  Cronet callback
-*/
+//
+// Cronet callback
+//
 static void on_write_completed(bidirectional_stream* stream, const char* data) {
   grpc_core::ApplicationCallbackExecCtx callback_exec_ctx;
   grpc_core::ExecCtx exec_ctx;
@@ -600,9 +601,9 @@ static void on_write_completed(bidirectional_stream* stream, const char* data) {
   execute_from_storage(s);
 }
 
-/*
-  Cronet callback
-*/
+//
+// Cronet callback
+//
 static void on_read_completed(bidirectional_stream* stream, char* data,
                               int count) {
   grpc_core::ApplicationCallbackExecCtx callback_exec_ctx;
@@ -639,9 +640,9 @@ static void on_read_completed(bidirectional_stream* stream, char* data,
   }
 }
 
-/*
-  Cronet callback
-*/
+//
+// Cronet callback
+//
 static void on_response_trailers_received(
     bidirectional_stream* stream,
     const bidirectional_stream_header_array* trailers) {
@@ -658,8 +659,8 @@ static void on_response_trailers_received(
     s->state.rs.trailing_metadata_valid = true;
   }
   s->state.state_callback_received[OP_RECV_TRAILING_METADATA] = true;
-  /* Send a EOS when server terminates the stream (testServerFinishesRequest) to
-   * trigger on_succeeded */
+  // Send a EOS when server terminates the stream (testServerFinishesRequest) to
+  // trigger on_succeeded
   if (!s->state.state_op_done[OP_SEND_TRAILING_METADATA] &&
       !(s->state.state_op_done[OP_CANCEL_ERROR] ||
         s->state.state_callback_received[OP_FAILED])) {
@@ -679,29 +680,29 @@ static void on_response_trailers_received(
   }
 }
 
-/*
- Utility function that takes the data from s->write_slice_buffer and assembles
- into a contiguous byte stream with 5 byte gRPC header prepended.
-*/
+//
+// Utility function that takes the data from s->write_slice_buffer and assembles
+// into a contiguous byte stream with 5 byte gRPC header prepended.
+//
 static void create_grpc_frame(grpc_slice_buffer* write_slice_buffer,
                               char** pp_write_buffer,
                               size_t* p_write_buffer_size, uint32_t flags) {
   size_t length = write_slice_buffer->length;
   *p_write_buffer_size = length + GRPC_HEADER_SIZE_IN_BYTES;
-  /* This is freed in the on_write_completed callback */
+  // This is freed in the on_write_completed callback
   char* write_buffer =
       static_cast<char*>(gpr_malloc(length + GRPC_HEADER_SIZE_IN_BYTES));
   *pp_write_buffer = write_buffer;
   uint8_t* p = reinterpret_cast<uint8_t*>(write_buffer);
-  /* Append 5 byte header */
-  /* Compressed flag */
+  // Append 5 byte header
+  // Compressed flag
   *p++ = static_cast<uint8_t>((flags & GRPC_WRITE_INTERNAL_COMPRESS) ? 1 : 0);
-  /* Message length */
+  // Message length
   *p++ = static_cast<uint8_t>(length >> 24);
   *p++ = static_cast<uint8_t>(length >> 16);
   *p++ = static_cast<uint8_t>(length >> 8);
   *p++ = static_cast<uint8_t>(length);
-  /* append actual data */
+  // append actual data
   size_t offset = 0;
   for (size_t i = 0; i < write_slice_buffer->count; ++i) {
     memcpy(p + offset, GRPC_SLICE_START_PTR(write_slice_buffer->slices[i]),
@@ -739,11 +740,11 @@ class CronetMetadataEncoder {
 
   void Encode(grpc_core::HttpSchemeMetadata,
               grpc_core::HttpSchemeMetadata::ValueType) {
-    /* Cronet populates these fields on its own */
+    // Cronet populates these fields on its own
   }
   void Encode(grpc_core::HttpAuthorityMetadata,
               const grpc_core::HttpAuthorityMetadata::ValueType&) {
-    /* Cronet populates these fields on its own */
+    // Cronet populates these fields on its own
   }
 
   void Encode(grpc_core::HttpMethodMetadata,
@@ -761,7 +762,7 @@ class CronetMetadataEncoder {
 
   void Encode(grpc_core::HttpPathMetadata,
               const grpc_core::HttpPathMetadata::ValueType& path) {
-    /* Create URL by appending :path value to the hostname */
+    // Create URL by appending :path value to the hostname
     *url_ = absl::StrCat("https://", host_, path.as_string_view());
   }
 
@@ -793,9 +794,9 @@ class CronetMetadataEncoder {
 };
 }  // namespace
 
-/*
- Convert metadata in a format that Cronet can consume
-*/
+//
+// Convert metadata in a format that Cronet can consume
+//
 static void convert_metadata_to_cronet_headers(
     grpc_metadata_batch* metadata, const char* host, std::string* pp_url,
     bidirectional_stream_header** pp_headers, size_t* p_num_headers,
@@ -821,19 +822,19 @@ static bool header_has_authority(const grpc_metadata_batch* b) {
   return b->get_pointer(grpc_core::HttpAuthorityMetadata()) != nullptr;
 }
 
-/*
-  Op Execution: Decide if one of the actions contained in the stream op can be
-  executed. This is the heart of the state machine.
-*/
+//
+// Op Execution: Decide if one of the actions contained in the stream op can be
+// executed. This is the heart of the state machine.
+//
 static bool op_can_be_run(grpc_transport_stream_op_batch* curr_op,
                           struct stream_obj* s, struct op_state* op_state,
                           enum e_op_id op_id) {
   struct op_state* stream_state = &s->state;
   grpc_cronet_transport* t = s->curr_ct;
   bool result = true;
-  /* When call is canceled, every op can be run, except under following
-  conditions
-  */
+  // When call is canceled, every op can be run, except under following
+  // conditions
+  //
   bool is_canceled_or_failed = stream_state->state_op_done[OP_CANCEL_ERROR] ||
                                stream_state->state_callback_received[OP_FAILED];
   if (is_canceled_or_failed) {
@@ -853,7 +854,7 @@ static bool op_can_be_run(grpc_transport_stream_op_batch* curr_op,
       CRONET_LOG(GPR_DEBUG, "Because");
       result = false;
     }
-    /* already executed */
+    // already executed
     if (op_id == OP_RECV_INITIAL_METADATA &&
         stream_state->state_op_done[OP_RECV_INITIAL_METADATA]) {
       CRONET_LOG(GPR_DEBUG, "Because");
@@ -868,11 +869,11 @@ static bool op_can_be_run(grpc_transport_stream_op_batch* curr_op,
       CRONET_LOG(GPR_DEBUG, "Because");
       result = false;
     }
-    /* ON_COMPLETE can be processed if one of the following conditions is met:
-     * 1. the stream failed
-     * 2. the stream is cancelled, and the callback is received
-     * 3. the stream succeeded before cancel is effective
-     * 4. the stream is cancelled, and the stream is never started */
+    // ON_COMPLETE can be processed if one of the following conditions is met:
+    // 1. the stream failed
+    // 2. the stream is cancelled, and the callback is received
+    // 3. the stream succeeded before cancel is effective
+    // 4. the stream is cancelled, and the stream is never started
     if (op_id == OP_ON_COMPLETE &&
         !(stream_state->state_callback_received[OP_FAILED] ||
           stream_state->state_callback_received[OP_CANCELED] ||
@@ -882,92 +883,92 @@ static bool op_can_be_run(grpc_transport_stream_op_batch* curr_op,
       result = false;
     }
   } else if (op_id == OP_SEND_INITIAL_METADATA) {
-    /* already executed */
+    // already executed
     if (stream_state->state_op_done[OP_SEND_INITIAL_METADATA]) result = false;
   } else if (op_id == OP_RECV_INITIAL_METADATA) {
     if (stream_state->state_op_done[OP_RECV_INITIAL_METADATA]) {
-      /* already executed */
+      // already executed
       result = false;
     } else if (!stream_state
                     ->state_callback_received[OP_SEND_INITIAL_METADATA]) {
-      /* we haven't sent headers yet. */
+      // we haven't sent headers yet.
       result = false;
     } else if (!stream_state
                     ->state_callback_received[OP_RECV_INITIAL_METADATA] &&
                !stream_state->state_op_done[OP_RECV_TRAILING_METADATA]) {
-      /* we haven't received headers yet. */
+      // we haven't received headers yet.
       result = false;
     }
   } else if (op_id == OP_SEND_MESSAGE) {
     if (op_state->state_op_done[OP_SEND_MESSAGE]) {
-      /* already executed (note we're checking op specific state, not stream
-         state) */
+      // already executed (note we're checking op specific state, not stream
+      // state)
       result = false;
     } else if (!stream_state
                     ->state_callback_received[OP_SEND_INITIAL_METADATA]) {
-      /* we haven't sent headers yet. */
+      // we haven't sent headers yet.
       result = false;
     }
   } else if (op_id == OP_RECV_MESSAGE) {
     if (op_state->state_op_done[OP_RECV_MESSAGE]) {
-      /* already executed */
+      // already executed
       result = false;
     } else if (!stream_state
                     ->state_callback_received[OP_RECV_INITIAL_METADATA] &&
                !stream_state->state_op_done[OP_RECV_TRAILING_METADATA]) {
-      /* we haven't received headers yet. */
+      // we haven't received headers yet.
       result = false;
     }
   } else if (op_id == OP_RECV_TRAILING_METADATA) {
     if (stream_state->state_op_done[OP_RECV_TRAILING_METADATA]) {
-      /* already executed */
+      // already executed
       result = false;
     } else if (stream_state->state_op_done[OP_READ_REQ_MADE] &&
                !stream_state->state_op_done[OP_RECV_MESSAGE]) {
-      /* we have asked for but haven't received message yet. */
+      // we have asked for but haven't received message yet.
       result = false;
     } else if (!stream_state
                     ->state_callback_received[OP_RECV_TRAILING_METADATA]) {
-      /* we haven't received trailers  yet. */
+      // we haven't received trailers  yet.
       result = false;
     } else if (!stream_state->state_callback_received[OP_SUCCEEDED]) {
-      /* we haven't received on_succeeded  yet. */
+      // we haven't received on_succeeded  yet.
       result = false;
     }
   } else if (op_id == OP_SEND_TRAILING_METADATA) {
     if (stream_state->state_op_done[OP_SEND_TRAILING_METADATA]) {
-      /* already executed */
+      // already executed
       result = false;
     } else if (!stream_state
                     ->state_callback_received[OP_SEND_INITIAL_METADATA]) {
-      /* we haven't sent initial metadata yet */
+      // we haven't sent initial metadata yet
       result = false;
     } else if (stream_state->pending_send_message &&
                !stream_state->state_op_done[OP_SEND_MESSAGE]) {
-      /* we haven't sent message yet */
+      // we haven't sent message yet
       result = false;
     } else if (stream_state->state_op_done[OP_SEND_MESSAGE] &&
                !stream_state->state_callback_received[OP_SEND_MESSAGE] &&
                !(t->use_packet_coalescing &&
                  stream_state->pending_write_for_trailer)) {
-      /* we haven't got on_write_completed for the send yet */
+      // we haven't got on_write_completed for the send yet
       result = false;
     }
   } else if (op_id == OP_CANCEL_ERROR) {
-    /* already executed */
+    // already executed
     if (stream_state->state_op_done[OP_CANCEL_ERROR]) result = false;
   } else if (op_id == OP_ON_COMPLETE) {
     if (op_state->state_op_done[OP_ON_COMPLETE]) {
-      /* already executed (note we're checking op specific state, not stream
-      state) */
+      // already executed (note we're checking op specific state, not stream
+      // state)
       CRONET_LOG(GPR_DEBUG, "Because");
       result = false;
     }
-    /* Check if every op that was asked for is done. */
-    /* TODO(muxi): We should not consider the recv ops here, since they
-     * have their own callbacks.  We should invoke a batch's on_complete
-     * as soon as all of the batch's send ops are complete, even if
-     * there are still recv ops pending. */
+    // Check if every op that was asked for is done.
+    // TODO(muxi): We should not consider the recv ops here, since they
+    // have their own callbacks.  We should invoke a batch's on_complete
+    // as soon as all of the batch's send ops are complete, even if
+    // there are still recv ops pending.
     else if (curr_op->send_initial_metadata &&
              !stream_state->state_callback_received[OP_SEND_INITIAL_METADATA]) {
       CRONET_LOG(GPR_DEBUG, "Because");
@@ -997,16 +998,16 @@ static bool op_can_be_run(grpc_transport_stream_op_batch* curr_op,
       CRONET_LOG(GPR_DEBUG, "Because");
       result = false;
     } else if (curr_op->recv_trailing_metadata) {
-      /* We aren't done with trailing metadata yet */
+      // We aren't done with trailing metadata yet
       if (!stream_state->state_op_done[OP_RECV_TRAILING_METADATA]) {
         CRONET_LOG(GPR_DEBUG, "Because");
         result = false;
       }
-      /* We've asked for actual message in an earlier op, and it hasn't been
-        delivered yet. */
+      // We've asked for actual message in an earlier op, and it hasn't been
+      // delivered yet.
       else if (stream_state->state_op_done[OP_READ_REQ_MADE]) {
-        /* If this op is not the one asking for read, (which means some earlier
-          op has asked), and the read hasn't been delivered. */
+        // If this op is not the one asking for read, (which means some earlier
+        // op has asked), and the read hasn't been delivered.
         if (!curr_op->recv_message &&
             !stream_state->state_callback_received[OP_SUCCEEDED]) {
           CRONET_LOG(GPR_DEBUG, "Because");
@@ -1014,8 +1015,8 @@ static bool op_can_be_run(grpc_transport_stream_op_batch* curr_op,
         }
       }
     }
-    /* We should see at least one on_write_completed for the trailers that we
-      sent */
+    // We should see at least one on_write_completed for the trailers that we
+    // sent
     else if (curr_op->send_trailing_metadata &&
              !stream_state->state_callback_received[OP_SEND_MESSAGE]) {
       result = false;
@@ -1026,9 +1027,9 @@ static bool op_can_be_run(grpc_transport_stream_op_batch* curr_op,
   return result;
 }
 
-/*
-  TODO (makdharma): Break down this function in smaller chunks for readability.
-*/
+//
+// TODO (makdharma): Break down this function in smaller chunks for readability.
+//
 static enum e_op_result execute_stream_op(struct op_and_state* oas) {
   grpc_transport_stream_op_batch* stream_op = &oas->op;
   struct stream_obj* s = oas->s;
@@ -1038,8 +1039,8 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
   if (stream_op->send_initial_metadata &&
       op_can_be_run(stream_op, s, &oas->state, OP_SEND_INITIAL_METADATA)) {
     CRONET_LOG(GPR_DEBUG, "running: %p OP_SEND_INITIAL_METADATA", oas);
-    /* Start new cronet stream. It is destroyed in on_succeeded, on_canceled,
-     * on_failed */
+    // Start new cronet stream. It is destroyed in on_succeeded, on_canceled,
+    // on_failed
     GPR_ASSERT(s->cbs == nullptr);
     GPR_ASSERT(!stream_state->state_op_done[OP_SEND_INITIAL_METADATA]);
     s->cbs =
@@ -1108,8 +1109,8 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
           result = ACTION_TAKEN_WITH_CALLBACK;
         }
       } else {
-        /* Should never reach here */
-        GPR_ASSERT(false);
+        // Should never reach here
+        grpc_core::Crash("unreachable");
       }
     }
     stream_state->state_op_done[OP_SEND_MESSAGE] = true;
@@ -1183,7 +1184,7 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
       oas->state.state_op_done[OP_RECV_MESSAGE] = true;
       result = ACTION_TAKEN_NO_CALLBACK;
     } else if (stream_state->rs.read_stream_closed) {
-      /* No more data will be received */
+      // No more data will be received
       CRONET_LOG(GPR_DEBUG, "read stream closed");
       grpc_core::ExecCtx::Run(
           DEBUG_LOCATION, stream_op->payload->recv_message.recv_message_ready,
@@ -1202,7 +1203,7 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
     } else if (!stream_state->rs.length_field_received) {
       if (stream_state->rs.received_bytes == GRPC_HEADER_SIZE_IN_BYTES &&
           stream_state->rs.remaining_bytes == 0) {
-        /* Start a read operation for data */
+        // Start a read operation for data
         stream_state->rs.length_field_received = true;
         parse_grpc_header(
             reinterpret_cast<const uint8_t*>(stream_state->rs.read_buffer),
@@ -1217,14 +1218,14 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
           stream_state->rs.received_bytes = 0;
           CRONET_LOG(GPR_DEBUG, "bidirectional_stream_read(%p)", s->cbs);
           stream_state->state_op_done[OP_READ_REQ_MADE] =
-              true; /* Indicates that at least one read request has been made */
+              true;  // Indicates that at least one read request has been made
           bidirectional_stream_read(s->cbs, stream_state->rs.read_buffer,
                                     stream_state->rs.remaining_bytes);
           result = ACTION_TAKEN_WITH_CALLBACK;
         } else {
           stream_state->rs.remaining_bytes = 0;
           CRONET_LOG(GPR_DEBUG, "read operation complete. Empty response.");
-          /* Clean up read_slice_buffer in case there is unread data. */
+          // Clean up read_slice_buffer in case there is unread data.
           stream_state->rs.read_slice_buffer.Clear();
           uint32_t flags = 0;
           if (stream_state->rs.compressed) {
@@ -1240,22 +1241,22 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
           stream_state->state_op_done[OP_RECV_MESSAGE] = true;
           oas->state.state_op_done[OP_RECV_MESSAGE] = true;
 
-          /* Extra read to trigger on_succeed */
+          // Extra read to trigger on_succeed
           stream_state->rs.length_field_received = false;
           stream_state->state_op_done[OP_READ_REQ_MADE] =
-              true; /* Indicates that at least one read request has been made */
+              true;  // Indicates that at least one read request has been made
           read_grpc_header(s);
           result = ACTION_TAKEN_NO_CALLBACK;
         }
       } else if (stream_state->rs.remaining_bytes == 0) {
-        /* Start a read operation for first 5 bytes (GRPC header) */
+        // Start a read operation for first 5 bytes (GRPC header)
         stream_state->rs.read_buffer = stream_state->rs.grpc_header_bytes;
         stream_state->rs.remaining_bytes = GRPC_HEADER_SIZE_IN_BYTES;
         stream_state->rs.received_bytes = 0;
         stream_state->rs.compressed = false;
         CRONET_LOG(GPR_DEBUG, "bidirectional_stream_read(%p)", s->cbs);
         stream_state->state_op_done[OP_READ_REQ_MADE] =
-            true; /* Indicates that at least one read request has been made */
+            true;  // Indicates that at least one read request has been made
         bidirectional_stream_read(s->cbs, stream_state->rs.read_buffer,
                                   stream_state->rs.remaining_bytes);
         result = ACTION_TAKEN_WITH_CALLBACK;
@@ -1270,7 +1271,7 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
       memcpy(dst_p, stream_state->rs.read_buffer,
              static_cast<size_t>(stream_state->rs.length_field));
       null_and_maybe_free_read_buffer(s);
-      /* Clean up read_slice_buffer in case there is unread data. */
+      // Clean up read_slice_buffer in case there is unread data.
       stream_state->rs.read_slice_buffer.Clear();
       stream_state->rs.read_slice_buffer.Append(
           grpc_core::Slice(read_data_slice));
@@ -1286,8 +1287,8 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
           absl::OkStatus());
       stream_state->state_op_done[OP_RECV_MESSAGE] = true;
       oas->state.state_op_done[OP_RECV_MESSAGE] = true;
-      /* Do an extra read to trigger on_succeeded() callback in case connection
-         is closed */
+      // Do an extra read to trigger on_succeeded() callback in case connection
+      // is closed
       stream_state->rs.length_field_received = false;
       read_grpc_header(s);
       result = ACTION_TAKEN_NO_CALLBACK;
@@ -1350,9 +1351,9 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
                                  error_message));
       }
     } else {
-      /* All actions in this stream_op are complete. Call the on_complete
-       * callback
-       */
+      // All actions in this stream_op are complete. Call the on_complete
+      // callback
+      //
       if (stream_op->on_complete) {
         grpc_core::ExecCtx::Run(DEBUG_LOCATION, stream_op->on_complete,
                                 absl::OkStatus());
@@ -1360,15 +1361,15 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
     }
     oas->state.state_op_done[OP_ON_COMPLETE] = true;
     oas->done = true;
-    /* reset any send message state, only if this ON_COMPLETE is about a send.
-     */
+    // reset any send message state, only if this ON_COMPLETE is about a send.
+    //
     if (stream_op->send_message) {
       stream_state->state_callback_received[OP_SEND_MESSAGE] = false;
       stream_state->state_op_done[OP_SEND_MESSAGE] = false;
     }
     result = ACTION_TAKEN_NO_CALLBACK;
-    /* If this is the on_complete callback being called for a received message -
-      make a note */
+    // If this is the on_complete callback being called for a received message -
+    // make a note
     if (stream_op->recv_message) {
       stream_state->state_op_done[OP_RECV_MESSAGE_AND_ON_COMPLETE] = true;
     }
@@ -1378,9 +1379,9 @@ static enum e_op_result execute_stream_op(struct op_and_state* oas) {
   return result;
 }
 
-/*
-  Functions used by upper layers to access transport functionality.
-*/
+//
+// Functions used by upper layers to access transport functionality.
+//
 
 inline stream_obj::stream_obj(grpc_transport* gt, grpc_stream* gs,
                               grpc_stream_refcount* refcount,
@@ -1416,8 +1417,8 @@ static void perform_stream_op(grpc_transport* /*gt*/, grpc_stream* gs,
   if (op->send_initial_metadata &&
       header_has_authority(
           op->payload->send_initial_metadata.send_initial_metadata)) {
-    /* Cronet does not support :authority header field. We cancel the call when
-     this field is present in metadata */
+    // Cronet does not support :authority header field. We cancel the call when
+    // this field is present in metadata
     if (op->recv_initial_metadata) {
       grpc_core::ExecCtx::Run(
           DEBUG_LOCATION,
