@@ -31,6 +31,7 @@
 #include <memory>
 #include <new>
 #include <string>
+#include <type_traits>
 #include <utility>
 
 #include "absl/container/inlined_vector.h"
@@ -40,7 +41,7 @@
 #include "absl/types/optional.h"
 
 #include <grpc/event_engine/event_engine.h>
-#include <grpc/impl/codegen/grpc_types.h>
+#include <grpc/grpc.h>
 #include <grpc/support/log.h>
 
 #include "src/core/lib/channel/call_finalization.h"
@@ -319,6 +320,8 @@ class BaseCallData : public Activity, private Wakeable {
       // We've got the completion callback, we'll close things out during poll
       // and then forward completion callbacks up and transition back to idle.
       kBatchCompleted,
+      // We're almost done, but need to poll first.
+      kCancelledButNotYetPolled,
       // We're done.
       kCancelled,
     };
@@ -393,15 +396,26 @@ class BaseCallData : public Activity, private Wakeable {
       kPulledFromPipe,
       // We're done.
       kCancelled,
+      // Call got terminated whilst we were idle: we need to close the sender
+      // pipe next poll.
+      kCancelledWhilstIdle,
       // Call got terminated whilst we had forwarded a recv_message down the
       // stack: we need to keep track of that until we get the completion so
       // that we do the right thing in OnComplete.
       kCancelledWhilstForwarding,
+      // The same, but before we got the pipe
+      kCancelledWhilstForwardingNoPipe,
       // Call got terminated whilst we had a recv_message batch completed, and
       // we've now received the completion.
       // On the next poll we'll close things out and forward on completions,
       // then transition to cancelled.
       kBatchCompletedButCancelled,
+      // The same, but before we got the pipe
+      kBatchCompletedButCancelledNoPipe,
+      // Completed successfully while we're processing a recv message - see
+      // kPushedToPipe.
+      kCompletedWhilePushedToPipe,
+      kCompletedWhilePulledFromPipe,
     };
     static const char* StateString(State);
 
