@@ -18,7 +18,7 @@
 #include <grpc/support/port_platform.h>
 
 namespace grpc_event_engine {
-namespace posix_engine {
+namespace experimental {
 
 class PosixEventPoller;
 class Scheduler;
@@ -27,7 +27,7 @@ class Scheduler;
 // scheduler.
 PosixEventPoller* MakeDefaultPoller(Scheduler* scheduler);
 
-}  // namespace posix_engine
+}  // namespace experimental
 }  // namespace grpc_event_engine
 
 #endif  // GRPC_CORE_LIB_EVENT_ENGINE_POSIX_ENGINE_EVENT_POLLER_POSIX_DEFAULT_H
