@@ -21,7 +21,7 @@
 #include "absl/status/statusor.h"
 
 namespace grpc_event_engine {
-namespace posix_engine {
+namespace experimental {
 
 class WakeupFd;
 
@@ -31,7 +31,7 @@ bool SupportsWakeupFd();
 // Create and return an initialized WakeupFd instance if supported.
 absl::StatusOr<std::unique_ptr<WakeupFd>> CreateWakeupFd();
 
-}  // namespace posix_engine
+}  // namespace experimental
 }  // namespace grpc_event_engine
 
-#endif  // GRPC_CORE_LIB_EVENT_ENGINE_POSIX_ENGINE_WAKEUP_FD_POSIX_DEFAULT_H
\ No newline at end of file
+#endif  // GRPC_CORE_LIB_EVENT_ENGINE_POSIX_ENGINE_WAKEUP_FD_POSIX_DEFAULT_H
