@@ -1,20 +1,20 @@
-/*
- *
- * Copyright 2015 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2015 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #ifndef GRPC_CORE_LIB_GPR_USEFUL_H
 #define GRPC_CORE_LIB_GPR_USEFUL_H
@@ -26,7 +26,7 @@
 #include "absl/strings/string_view.h"
 #include "absl/types/variant.h"
 
-/** useful utilities that don't belong anywhere else */
+/// useful utilities that don't belong anywhere else
 
 namespace grpc_core {
 
@@ -37,7 +37,7 @@ T Clamp(T val, T min, T max) {
   return val;
 }
 
-/** rotl, rotr assume x is unsigned */
+/// rotl, rotr assume x is unsigned
 template <typename T>
 constexpr T RotateLeft(T x, T n) {
   return ((x << n) | (x >> (sizeof(x) * 8 - n)));
@@ -80,15 +80,28 @@ inline constexpr uint32_t BitCount(uint32_t i) {
 }
 
 inline constexpr uint32_t BitCount(uint64_t i) {
-  return BitCount(uint32_t(i)) + BitCount(uint32_t(i >> 32));
+  return BitCount(static_cast<uint32_t>(i)) +
+         BitCount(static_cast<uint32_t>(i >> 32));
 }
 
-inline constexpr uint32_t BitCount(uint16_t i) { return BitCount(uint32_t(i)); }
-inline constexpr uint32_t BitCount(uint8_t i) { return BitCount(uint32_t(i)); }
-inline constexpr uint32_t BitCount(int64_t i) { return BitCount(uint64_t(i)); }
-inline constexpr uint32_t BitCount(int32_t i) { return BitCount(uint32_t(i)); }
-inline constexpr uint32_t BitCount(int16_t i) { return BitCount(uint16_t(i)); }
-inline constexpr uint32_t BitCount(int8_t i) { return BitCount(uint8_t(i)); }
+inline constexpr uint32_t BitCount(uint16_t i) {
+  return BitCount(static_cast<uint32_t>(i));
+}
+inline constexpr uint32_t BitCount(uint8_t i) {
+  return BitCount(static_cast<uint32_t>(i));
+}
+inline constexpr uint32_t BitCount(int64_t i) {
+  return BitCount(static_cast<uint64_t>(i));
+}
+inline constexpr uint32_t BitCount(int32_t i) {
+  return BitCount(static_cast<uint32_t>(i));
+}
+inline constexpr uint32_t BitCount(int16_t i) {
+  return BitCount(static_cast<uint16_t>(i));
+}
+inline constexpr uint32_t BitCount(int8_t i) {
+  return BitCount(static_cast<uint8_t>(i));
+}
 
 // This function uses operator< to implement a qsort-style comparison, whereby:
 // if a is smaller than b, a number smaller than 0 is returned.
@@ -168,4 +181,4 @@ inline uint32_t RoundUpToPowerOf2(uint32_t v) {
 
 #define GPR_ARRAY_SIZE(array) (sizeof(array) / sizeof(*(array)))
 
-#endif /* GRPC_CORE_LIB_GPR_USEFUL_H */
+#endif  // GRPC_CORE_LIB_GPR_USEFUL_H
