@@ -1,20 +1,20 @@
-/*
- *
- * Copyright 2015 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2015 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #include <grpc/support/port_platform.h>
 
@@ -34,17 +34,17 @@ namespace grpc_core {
 
 namespace {
 
-/* The idea of the writer is basically symmetrical of the reader. While the
- * reader emits various calls to your code, the writer takes basically the
- * same calls and emit json out of it. It doesn't try to make any check on
- * the order of the calls you do on it. Meaning you can theorically force
- * it to generate invalid json.
- *
- * Also, unlike the reader, the writer expects UTF-8 encoded input strings.
- * These strings will be UTF-8 validated, and any invalid character will
- * cut the conversion short, before any invalid UTF-8 sequence, thus forming
- * a valid UTF-8 string overall.
- */
+// The idea of the writer is basically symmetrical of the reader. While the
+// reader emits various calls to your code, the writer takes basically the
+// same calls and emit json out of it. It doesn't try to make any check on
+// the order of the calls you do on it. Meaning you can theorically force
+// it to generate invalid json.
+//
+// Also, unlike the reader, the writer expects UTF-8 encoded input strings.
+// These strings will be UTF-8 validated, and any invalid character will
+// cut the conversion short, before any invalid UTF-8 sequence, thus forming
+// a valid UTF-8 string overall.
+//
 class JsonWriter {
  public:
   static std::string Dump(const Json& value, int indent);
@@ -76,15 +76,15 @@ class JsonWriter {
   std::string output_;
 };
 
-/* This function checks if there's enough space left in the output buffer,
- * and will enlarge it if necessary. We're only allocating chunks of 256
- * bytes at a time (or multiples thereof).
- */
+// This function checks if there's enough space left in the output buffer,
+// and will enlarge it if necessary. We're only allocating chunks of 256
+// bytes at a time (or multiples thereof).
+//
 void JsonWriter::OutputCheck(size_t needed) {
   size_t free_space = output_.capacity() - output_.size();
   if (free_space >= needed) return;
   needed -= free_space;
-  /* Round up by 256 bytes. */
+  // Round up by 256 bytes.
   needed = (needed + 0xff) & ~0xffU;
   output_.reserve(output_.capacity() + needed);
 }
@@ -191,13 +191,13 @@ void JsonWriter::EscapeString(const std::string& string) {
       for (i = 0; i < extra; i++) {
         utf32 <<= 6;
         ++idx;
-        /* Breaks out and bail if we hit the end of the string. */
+        // Breaks out and bail if we hit the end of the string.
         if (idx == string.size()) {
           valid = 0;
           break;
         }
         c = static_cast<uint8_t>(string[idx]);
-        /* Breaks out and bail on any invalid UTF-8 sequence, including \0. */
+        // Breaks out and bail on any invalid UTF-8 sequence, including \0.
         if ((c & 0xc0) != 0x80) {
           valid = 0;
           break;
@@ -205,30 +205,30 @@ void JsonWriter::EscapeString(const std::string& string) {
         utf32 |= c & 0x3f;
       }
       if (!valid) break;
-      /* The range 0xd800 - 0xdfff is reserved by the surrogates ad vitam.
-       * Any other range is technically reserved for future usage, so if we
-       * don't want the software to break in the future, we have to allow
-       * anything else. The first non-unicode character is 0x110000. */
+      // The range 0xd800 - 0xdfff is reserved by the surrogates ad vitam.
+      // Any other range is technically reserved for future usage, so if we
+      // don't want the software to break in the future, we have to allow
+      // anything else. The first non-unicode character is 0x110000.
       if (((utf32 >= 0xd800) && (utf32 <= 0xdfff)) || (utf32 >= 0x110000)) {
         break;
       }
       if (utf32 >= 0x10000) {
-        /* If utf32 contains a character that is above 0xffff, it needs to be
-         * broken down into a utf-16 surrogate pair. A surrogate pair is first
-         * a high surrogate, followed by a low surrogate. Each surrogate holds
-         * 10 bits of usable data, thus allowing a total of 20 bits of data.
-         * The high surrogate marker is 0xd800, while the low surrogate marker
-         * is 0xdc00. The low 10 bits of each will be the usable data.
-         *
-         * After re-combining the 20 bits of data, one has to add 0x10000 to
-         * the resulting value, in order to obtain the original character.
-         * This is obviously because the range 0x0000 - 0xffff can be written
-         * without any special trick.
-         *
-         * Since 0x10ffff is the highest allowed character, we're working in
-         * the range 0x00000 - 0xfffff after we decrement it by 0x10000.
-         * That range is exactly 20 bits.
-         */
+        // If utf32 contains a character that is above 0xffff, it needs to be
+        // broken down into a utf-16 surrogate pair. A surrogate pair is first
+        // a high surrogate, followed by a low surrogate. Each surrogate holds
+        // 10 bits of usable data, thus allowing a total of 20 bits of data.
+        // The high surrogate marker is 0xd800, while the low surrogate marker
+        // is 0xdc00. The low 10 bits of each will be the usable data.
+        //
+        // After re-combining the 20 bits of data, one has to add 0x10000 to
+        // the resulting value, in order to obtain the original character.
+        // This is obviously because the range 0x0000 - 0xffff can be written
+        // without any special trick.
+        //
+        // Since 0x10ffff is the highest allowed character, we're working in
+        // the range 0x00000 - 0xfffff after we decrement it by 0x10000.
+        // That range is exactly 20 bits.
+        //
         utf32 -= 0x10000;
         EscapeUtf16(static_cast<uint16_t>(0xd800 | (utf32 >> 10)));
         EscapeUtf16(static_cast<uint16_t>(0xdc00 | (utf32 & 0x3ff)));
@@ -283,7 +283,7 @@ void JsonWriter::ValueString(const std::string& string) {
 void JsonWriter::DumpObject(const Json::Object& object) {
   ContainerBegins(Json::Type::OBJECT);
   for (const auto& p : object) {
-    ObjectKey(p.first.data());
+    ObjectKey(p.first);
     DumpValue(p.second);
   }
   ContainerEnds(Json::Type::OBJECT);
