@@ -1,20 +1,20 @@
-/*
- *
- * Copyright 2015 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2015 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #include "test/core/bad_client/bad_client.h"
 
@@ -46,7 +46,7 @@
 
 #define MIN_HTTP2_FRAME_SIZE 9
 
-/* Args to provide to thread running server side validator */
+// Args to provide to thread running server side validator
 typedef struct {
   grpc_server* server;
   grpc_completion_queue* cq;
@@ -55,7 +55,7 @@ typedef struct {
   gpr_event done_thd;
 } thd_args;
 
-/* Run the server side validator and set done_thd once done */
+// Run the server side validator and set done_thd once done
 static void thd_func(void* arg) {
   thd_args* a = static_cast<thd_args*>(arg);
   if (a->validator != nullptr) {
@@ -64,7 +64,7 @@ static void thd_func(void* arg) {
   gpr_event_set(&a->done_thd, reinterpret_cast<void*>(1));
 }
 
-/* Sets the done_write event */
+// Sets the done_write event
 static void set_done_write(void* arg, grpc_error_handle /*error*/) {
   gpr_event* done_write = static_cast<gpr_event*>(arg);
   gpr_event_set(done_write, reinterpret_cast<void*>(1));
@@ -81,13 +81,13 @@ static void server_setup_transport(void* ts, grpc_transport* transport) {
                                   /*socket_node=*/nullptr)));
 }
 
-/* Sets the read_done event */
+// Sets the read_done event
 static void set_read_done(void* arg, grpc_error_handle /*error*/) {
   gpr_event* read_done = static_cast<gpr_event*>(arg);
   gpr_event_set(read_done, reinterpret_cast<void*>(1));
 }
 
-/* shutdown client */
+// shutdown client
 static void shutdown_client(grpc_endpoint** client_fd) {
   if (*client_fd != nullptr) {
     grpc_endpoint_shutdown(*client_fd, GRPC_ERROR_CREATE("Forced Disconnect"));
@@ -97,7 +97,7 @@ static void shutdown_client(grpc_endpoint** client_fd) {
   }
 }
 
-/* Runs client side validator */
+// Runs client side validator
 void grpc_run_client_side_validator(grpc_bad_client_arg* arg, uint32_t flags,
                                     grpc_endpoint_pair* sfd,
                                     grpc_completion_queue* client_cq) {
@@ -106,7 +106,7 @@ void grpc_run_client_side_validator(grpc_bad_client_arg* arg, uint32_t flags,
   if (arg->client_payload_length < 4 * 1024) {
     hex = gpr_dump(arg->client_payload, arg->client_payload_length,
                    GPR_DUMP_HEX | GPR_DUMP_ASCII);
-    /* Add a debug log */
+    // Add a debug log
     gpr_log(GPR_INFO, "TEST: %s", hex);
     gpr_free(hex);
   } else {
@@ -125,13 +125,13 @@ void grpc_run_client_side_validator(grpc_bad_client_arg* arg, uint32_t flags,
   GRPC_CLOSURE_INIT(&done_write_closure, set_done_write, &done_write,
                     grpc_schedule_on_exec_ctx);
 
-  /* Write data */
+  // Write data
   grpc_endpoint_write(sfd->client, &outgoing, &done_write_closure, nullptr,
                       /*max_frame_size=*/INT_MAX);
   grpc_core::ExecCtx::Get()->Flush();
 
-  /* Await completion, unless the request is large and write may not finish
-   * before the peer shuts down. */
+  // Await completion, unless the request is large and write may not finish
+  // before the peer shuts down.
   if (!(flags & GRPC_BAD_CLIENT_LARGE_REQUEST)) {
     GPR_ASSERT(
         gpr_event_wait(&done_write, grpc_timeout_seconds_to_deadline(5)));
@@ -142,13 +142,13 @@ void grpc_run_client_side_validator(grpc_bad_client_arg* arg, uint32_t flags,
   }
 
   if (sfd->client != nullptr) {
-    /* Validate client stream, if requested. */
+    // Validate client stream, if requested.
     if (arg->client_validator != nullptr) {
       gpr_timespec deadline = grpc_timeout_seconds_to_deadline(5);
       grpc_slice_buffer incoming;
       grpc_slice_buffer_init(&incoming);
-      /* We may need to do multiple reads to read the complete server
-       * response. */
+      // We may need to do multiple reads to read the complete server
+      // response.
       while (true) {
         gpr_event read_done_event;
         gpr_event_init(&read_done_event);
@@ -160,8 +160,8 @@ void grpc_run_client_side_validator(grpc_bad_client_arg* arg, uint32_t flags,
         grpc_core::ExecCtx::Get()->Flush();
         do {
           GPR_ASSERT(gpr_time_cmp(deadline, gpr_now(deadline.clock_type)) > 0);
-          /* Perform a cq next just to provide a thread that can read incoming
-           bytes on the client fd */
+          // Perform a cq next just to provide a thread that can read incoming
+          // bytes on the client fd
           GPR_ASSERT(grpc_completion_queue_next(
                          client_cq, grpc_timeout_milliseconds_to_deadline(100),
                          nullptr)
@@ -177,13 +177,13 @@ void grpc_run_client_side_validator(grpc_bad_client_arg* arg, uint32_t flags,
     grpc_core::ExecCtx::Get()->Flush();
   }
 
-  /* If the request was too large, then we need to forcefully shut down the
-   * client, so that the write can be considered completed */
+  // If the request was too large, then we need to forcefully shut down the
+  // client, so that the write can be considered completed
   if (flags & GRPC_BAD_CLIENT_LARGE_REQUEST) {
     shutdown_client(&sfd->client);
   }
 
-  /* Make sure that the client is done writing */
+  // Make sure that the client is done writing
   while (!gpr_event_get(&done_write)) {
     GPR_ASSERT(
         grpc_completion_queue_next(
@@ -205,11 +205,11 @@ void grpc_run_bad_client_test(
   grpc_completion_queue* shutdown_cq;
   grpc_completion_queue* client_cq;
 
-  /* Init grpc */
+  // Init grpc
   grpc_init();
 
   sfd = grpc_iomgr_create_endpoint_pair("fixture", nullptr);
-  /* Create server, completion events */
+  // Create server, completion events
   a.server = grpc_server_create(nullptr, nullptr);
   a.cq = grpc_completion_queue_create_for_next(nullptr);
   client_cq = grpc_completion_queue_create_for_next(nullptr);
@@ -227,16 +227,16 @@ void grpc_run_bad_client_test(
   server_setup_transport(&a, transport);
   grpc_chttp2_transport_start_reading(transport, nullptr, nullptr, nullptr);
 
-  /* Bind fds to pollsets */
+  // Bind fds to pollsets
   grpc_endpoint_add_to_pollset(sfd.client, grpc_cq_pollset(client_cq));
   grpc_endpoint_add_to_pollset(sfd.server, grpc_cq_pollset(a.cq));
 
-  /* Check a ground truth */
+  // Check a ground truth
   GPR_ASSERT(grpc_core::Server::FromC(a.server)->HasOpenConnections());
 
   gpr_event_init(&a.done_thd);
   a.validator = server_validator;
-  /* Start validator */
+  // Start validator
 
   grpc_core::Thread server_validator_thd("grpc_bad_client", thd_func, &a);
   server_validator_thd.Start();
@@ -244,10 +244,10 @@ void grpc_run_bad_client_test(
     grpc_run_client_side_validator(&args[i], i == (num_args - 1) ? flags : 0,
                                    &sfd, client_cq);
   }
-  /* Wait for server thread to finish */
+  // Wait for server thread to finish
   GPR_ASSERT(gpr_event_wait(&a.done_thd, grpc_timeout_seconds_to_deadline(1)));
 
-  /* Shutdown. */
+  // Shutdown.
   shutdown_client(&sfd.client);
   server_validator_thd.Join();
   shutdown_cq = grpc_completion_queue_create_for_pluck(nullptr);
@@ -269,16 +269,16 @@ bool client_connection_preface_validator(grpc_slice_buffer* incoming,
     return false;
   }
   grpc_slice slice = incoming->slices[0];
-  /* There should be at least one settings frame present */
+  // There should be at least one settings frame present
   if (GRPC_SLICE_LENGTH(slice) < MIN_HTTP2_FRAME_SIZE) {
     return false;
   }
   const uint8_t* p = GRPC_SLICE_START_PTR(slice);
-  /* Check the frame type (SETTINGS) */
+  // Check the frame type (SETTINGS)
   return *(p + 3) == 4;
 }
 
-/* connection preface and settings frame to be sent by the client */
+// connection preface and settings frame to be sent by the client
 #define CONNECTION_PREFACE_FROM_CLIENT \
   "PRI * HTTP/2.0\r\n\r\nSM\r\n\r\n"   \
   "\x00\x00\x00\x04\x00\x00\x00\x00\x00"
