@@ -1,29 +1,31 @@
-/*
- *
- * Copyright 2015 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2015 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #include <stdint.h>
 #include <string.h>
 
+#include <string>
+
 #include "absl/strings/match.h"
 
 #include <grpc/byte_buffer.h>
 #include <grpc/grpc.h>
-#include <grpc/impl/codegen/propagation_bits.h>
+#include <grpc/impl/propagation_bits.h>
 #include <grpc/slice.h>
 #include <grpc/status.h>
 #include <grpc/support/log.h>
@@ -43,7 +45,10 @@ static grpc_end2end_test_fixture begin_test(grpc_end2end_test_config config,
                                             grpc_channel_args* client_args,
                                             grpc_channel_args* server_args) {
   grpc_end2end_test_fixture f;
-  gpr_log(GPR_INFO, "Running test: %s/%s", test_name, config.name);
+  gpr_log(GPR_INFO, "\n\n\nRunning test: %s/%s client_args=%s server_args=%s",
+          test_name, config.name,
+          grpc_core::ChannelArgs::FromC(client_args).ToString().c_str(),
+          grpc_core::ChannelArgs::FromC(server_args).ToString().c_str());
   // We intentionally do not pass the client and server args to
   // create_fixture(), since we don't want the limit enforced on the
   // proxy, only on the backend server.
@@ -482,11 +487,8 @@ static grpc_metadata gzip_compression_override() {
 
 // Test receive message limit with compressed request larger than the limit
 static void test_max_receive_message_length_on_compressed_request(
-    grpc_end2end_test_config config, bool minimal_stack) {
-  gpr_log(GPR_INFO,
-          "test max receive message length on compressed request with "
-          "minimal_stack=%d",
-          minimal_stack);
+    grpc_end2end_test_config config) {
+  gpr_log(GPR_INFO, "test max receive message length on compressed request");
   grpc_end2end_test_fixture f;
   grpc_call* c = nullptr;
   grpc_call* s = nullptr;
@@ -503,17 +505,15 @@ static void test_max_receive_message_length_on_compressed_request(
   grpc_call_details call_details;
   grpc_status_code status;
   grpc_call_error error;
-  grpc_slice details, status_details;
+  grpc_slice details;
   int was_cancelled = 2;
 
   // Set limit via channel args.
-  grpc_arg arg[2];
+  grpc_arg arg[1];
   arg[0] = grpc_channel_arg_integer_create(
       const_cast<char*>(GRPC_ARG_MAX_RECEIVE_MESSAGE_LENGTH), 5);
-  arg[1] = grpc_channel_arg_integer_create(
-      const_cast<char*>(GRPC_ARG_MINIMAL_STACK), minimal_stack);
   grpc_channel_args* server_args =
-      grpc_channel_args_copy_and_add(nullptr, arg, 2);
+      grpc_channel_args_copy_and_add(nullptr, arg, 1);
 
   f = begin_test(config, "test_max_request_message_length", nullptr,
                  server_args);
@@ -576,50 +576,36 @@ static void test_max_receive_message_length_on_compressed_request(
 
   memset(ops, 0, sizeof(ops));
   op = ops;
-  op->op = GRPC_OP_RECV_CLOSE_ON_SERVER;
-  op->data.recv_close_on_server.cancelled = &was_cancelled;
-  op->flags = 0;
-  op->reserved = nullptr;
-  op++;
   op->op = GRPC_OP_RECV_MESSAGE;
   op->data.recv_message.recv_message = &recv_payload;
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  if (minimal_stack) {
-    /* Expect the RPC to proceed normally for a minimal stack */
-    op->op = GRPC_OP_SEND_INITIAL_METADATA;
-    op->data.send_initial_metadata.count = 0;
-    op->flags = 0;
-    op->reserved = nullptr;
-    op++;
-    op->op = GRPC_OP_SEND_STATUS_FROM_SERVER;
-    op->data.send_status_from_server.trailing_metadata_count = 0;
-    op->data.send_status_from_server.status = GRPC_STATUS_OK;
-    status_details = grpc_slice_from_static_string("xyz");
-    op->data.send_status_from_server.status_details = &status_details;
-    op->flags = 0;
-    op->reserved = nullptr;
-    op++;
-  }
   error = grpc_call_start_batch(s, ops, static_cast<size_t>(op - ops), tag(102),
                                 nullptr);
   GPR_ASSERT(GRPC_CALL_OK == error);
 
-  cqv.Expect(tag(102), true);
+  memset(ops, 0, sizeof(ops));
+  op = ops;
+  op->op = GRPC_OP_RECV_CLOSE_ON_SERVER;
+  op->data.recv_close_on_server.cancelled = &was_cancelled;
+  op->flags = 0;
+  op->reserved = nullptr;
+  op++;
+  error = grpc_call_start_batch(s, ops, static_cast<size_t>(op - ops), tag(103),
+                                nullptr);
+  GPR_ASSERT(GRPC_CALL_OK == error);
+
+  cqv.Expect(tag(102), false);
+  cqv.Expect(tag(103), true);
   cqv.Expect(tag(1), true);
   cqv.Verify();
 
   GPR_ASSERT(0 == grpc_slice_str_cmp(call_details.method, "/service/method"));
-  if (minimal_stack) {
-    /* We do not perform message size checks for minimal stack. */
-    GPR_ASSERT(status == GRPC_STATUS_OK);
-  } else {
-    GPR_ASSERT(was_cancelled == 1);
-    GPR_ASSERT(status == GRPC_STATUS_RESOURCE_EXHAUSTED);
-    GPR_ASSERT(absl::StartsWith(grpc_core::StringViewFromSlice(details),
-                                "Received message larger than max"));
-  }
+  GPR_ASSERT(was_cancelled == 1);
+  GPR_ASSERT(status == GRPC_STATUS_RESOURCE_EXHAUSTED);
+  GPR_ASSERT(absl::StartsWith(grpc_core::StringViewFromSlice(details),
+                              "Received message larger than max"));
   grpc_slice_unref(details);
   grpc_slice_unref(request_payload_slice);
   grpc_metadata_array_destroy(&initial_metadata_recv);
@@ -637,11 +623,9 @@ static void test_max_receive_message_length_on_compressed_request(
 
 // Test receive message limit with compressed response larger than the limit.
 static void test_max_receive_message_length_on_compressed_response(
-    grpc_end2end_test_config config, bool minimal_stack) {
+    grpc_end2end_test_config config) {
   gpr_log(GPR_INFO,
-          "testing max receive message length on compressed response with "
-          "minimal_stack=%d",
-          minimal_stack);
+          "testing max receive message length on compressed response");
   grpc_end2end_test_fixture f;
   grpc_call* c = nullptr;
   grpc_call* s = nullptr;
@@ -662,13 +646,11 @@ static void test_max_receive_message_length_on_compressed_response(
   int was_cancelled = 2;
 
   // Set limit via channel args.
-  grpc_arg arg[2];
+  grpc_arg arg[1];
   arg[0] = grpc_channel_arg_integer_create(
       const_cast<char*>(GRPC_ARG_MAX_RECEIVE_MESSAGE_LENGTH), 5);
-  arg[1] = grpc_channel_arg_integer_create(
-      const_cast<char*>(GRPC_ARG_MINIMAL_STACK), minimal_stack);
   grpc_channel_args* client_args =
-      grpc_channel_args_copy_and_add(nullptr, arg, 2);
+      grpc_channel_args_copy_and_add(nullptr, arg, 1);
 
   f = begin_test(config, "test_max_response_message_length", client_args,
                  nullptr);
@@ -764,14 +746,9 @@ static void test_max_receive_message_length_on_compressed_response(
   cqv.Verify();
 
   GPR_ASSERT(0 == grpc_slice_str_cmp(call_details.method, "/service/method"));
-  if (minimal_stack) {
-    /* We do not perform message size checks for minimal stack. */
-    GPR_ASSERT(status == GRPC_STATUS_OK);
-  } else {
-    GPR_ASSERT(status == GRPC_STATUS_RESOURCE_EXHAUSTED);
-    GPR_ASSERT(absl::StartsWith(grpc_core::StringViewFromSlice(details),
-                                "Received message larger than max"));
-  }
+  GPR_ASSERT(status == GRPC_STATUS_RESOURCE_EXHAUSTED);
+  GPR_ASSERT(absl::StartsWith(grpc_core::StringViewFromSlice(details),
+                              "Received message larger than max"));
   grpc_slice_unref(details);
   grpc_slice_unref(response_payload_slice);
   grpc_metadata_array_destroy(&initial_metadata_recv);
@@ -813,14 +790,12 @@ void max_message_length(grpc_end2end_test_config config) {
   test_max_message_length_on_response(config, false /* send_limit */,
                                       true /* use_service_config */,
                                       true /* use_string_json_value */);
-  /* The following tests are not useful for inproc transport and do not work
-   * with our simple proxy. */
+  // The following tests are not useful for inproc transport and do not work
+  // with our simple proxy.
   if (strcmp(config.name, "inproc") != 0 &&
       (config.feature_mask & FEATURE_MASK_SUPPORTS_REQUEST_PROXYING) == 0) {
-    test_max_receive_message_length_on_compressed_request(config, false);
-    test_max_receive_message_length_on_compressed_request(config, true);
-    test_max_receive_message_length_on_compressed_response(config, false);
-    test_max_receive_message_length_on_compressed_response(config, true);
+    test_max_receive_message_length_on_compressed_request(config);
+    test_max_receive_message_length_on_compressed_response(config);
   }
 }
 
