@@ -1,20 +1,20 @@
-/*
- *
- * Copyright 2018 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2018 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #include <grpc/support/port_platform.h>
 
@@ -47,6 +47,7 @@
 #include <grpcpp/server_builder.h>
 
 #include "src/core/lib/gpr/useful.h"
+#include "src/core/lib/gprpp/crash.h"
 #include "src/core/lib/gprpp/host_port.h"
 #include "src/core/lib/gprpp/thd.h"
 #include "src/core/lib/iomgr/error.h"
@@ -114,8 +115,7 @@ class FakeHandshakeServer {
           0 /* expected max concurrent rpcs unset */);
     }
     grpc::ServerBuilder builder;
-    builder.AddListeningPort(address_.c_str(),
-                             grpc::InsecureServerCredentials());
+    builder.AddListeningPort(address_, grpc::InsecureServerCredentials());
     builder.RegisterService(service_.get());
     // TODO(apolcyn): when removing the global concurrent handshake limiting
     // queue, set MAX_CONCURRENT_STREAMS on this server.
@@ -296,8 +296,8 @@ TEST(AltsConcurrentConnectivityTest, TestBasicClientServerHandshakes) {
   }
 }
 
-/* Run a bunch of concurrent ALTS handshakes on concurrent channels
- * (using the fake, in-process handshake server). */
+// Run a bunch of concurrent ALTS handshakes on concurrent channels
+// (using the fake, in-process handshake server).
 TEST(AltsConcurrentConnectivityTest, TestConcurrentClientServerHandshakes) {
   FakeHandshakeServer fake_handshake_server(
       true /* check num concurrent rpcs */);
@@ -320,17 +320,16 @@ TEST(AltsConcurrentConnectivityTest, TestConcurrentClientServerHandshakes) {
     gpr_log(GPR_DEBUG,
             "done performing concurrent expected-to-succeed connects");
     if (gpr_time_cmp(gpr_now(GPR_CLOCK_MONOTONIC), test_deadline) > 0) {
-      gpr_log(GPR_DEBUG, "Test took longer than expected.");
-      abort();
+      grpc_core::Crash("Test took longer than expected.");
     }
   }
 }
 
-/* This test is intended to make sure that ALTS handshakes we correctly
- * fail fast when the security handshaker gets an error while reading
- * from the remote peer, after having earlier sent the first bytes of the
- * ALTS handshake to the peer, i.e. after getting into the middle of a
- * handshake. */
+// This test is intended to make sure that ALTS handshakes we correctly
+// fail fast when the security handshaker gets an error while reading
+// from the remote peer, after having earlier sent the first bytes of the
+// ALTS handshake to the peer, i.e. after getting into the middle of a
+// handshake.
 TEST(AltsConcurrentConnectivityTest,
      TestHandshakeFailsFastWhenPeerEndpointClosesConnectionAfterAccepting) {
   // Don't enforce the number of concurrent rpcs for the fake handshake
@@ -364,16 +363,15 @@ TEST(AltsConcurrentConnectivityTest,
     connect_loop_runners.clear();
     gpr_log(GPR_DEBUG, "done performing concurrent expected-to-fail connects");
     if (gpr_time_cmp(gpr_now(GPR_CLOCK_MONOTONIC), test_deadline) > 0) {
-      gpr_log(GPR_ERROR,
-              "Exceeded test deadline. ALTS handshakes might not be failing "
-              "fast when the peer endpoint closes the connection abruptly");
-      abort();
+      grpc_core::Crash(
+          "Exceeded test deadline. ALTS handshakes might not be failing "
+          "fast when the peer endpoint closes the connection abruptly");
     }
   }
 }
 
-/* This test is intended to make sure that ALTS handshakes correctly
- * fail fast when the ALTS handshake server fails incoming handshakes fast. */
+// This test is intended to make sure that ALTS handshakes correctly
+// fail fast when the ALTS handshake server fails incoming handshakes fast.
 TEST(AltsConcurrentConnectivityTest,
      TestHandshakeFailsFastWhenHandshakeServerClosesConnectionAfterAccepting) {
   // The fake_handshake_server emulates a broken ALTS handshaker, which
@@ -403,17 +401,16 @@ TEST(AltsConcurrentConnectivityTest,
     connect_loop_runners.clear();
     gpr_log(GPR_DEBUG, "done performing concurrent expected-to-fail connects");
     if (gpr_time_cmp(gpr_now(GPR_CLOCK_MONOTONIC), test_deadline) > 0) {
-      gpr_log(GPR_ERROR,
-              "Exceeded test deadline. ALTS handshakes might not be failing "
-              "fast when the handshake server closes new connections");
-      abort();
+      grpc_core::Crash(
+          "Exceeded test deadline. ALTS handshakes might not be failing "
+          "fast when the handshake server closes new connections");
     }
   }
 }
 
-/* This test is intended to make sure that ALTS handshakes correctly
- * fail fast when the ALTS handshake server is non-responsive, in which case
- * the overall connection deadline kicks in. */
+// This test is intended to make sure that ALTS handshakes correctly
+// fail fast when the ALTS handshake server is non-responsive, in which case
+// the overall connection deadline kicks in.
 TEST(AltsConcurrentConnectivityTest,
      TestHandshakeFailsFastWhenHandshakeServerHangsAfterAccepting) {
   // fake_handshake_server emulates an insecure server, so send settings first.
@@ -442,10 +439,9 @@ TEST(AltsConcurrentConnectivityTest,
     connect_loop_runners.clear();
     gpr_log(GPR_DEBUG, "done performing concurrent expected-to-fail connects");
     if (gpr_time_cmp(gpr_now(GPR_CLOCK_MONOTONIC), test_deadline) > 0) {
-      gpr_log(GPR_ERROR,
-              "Exceeded test deadline. ALTS handshakes might not be failing "
-              "fast when the handshake server is non-response timeout occurs");
-      abort();
+      grpc_core::Crash(
+          "Exceeded test deadline. ALTS handshakes might not be failing "
+          "fast when the handshake server is non-response timeout occurs");
     }
   }
 }
