@@ -1,20 +1,20 @@
-/*
- *
- * Copyright 2017 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2017 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #include "test/core/tsi/transport_security_test_lib.h"
 
@@ -26,6 +26,7 @@
 #include <grpc/support/alloc.h>
 #include <grpc/support/log.h>
 
+#include "src/core/lib/gprpp/crash.h"
 #include "src/core/lib/gprpp/memory.h"
 #include "src/core/lib/security/transport/tsi_error.h"
 
@@ -106,9 +107,9 @@ static void check_handshake_results(tsi_test_fixture* fixture) {
   GPR_ASSERT(fixture != nullptr);
   GPR_ASSERT(fixture->vtable != nullptr);
   GPR_ASSERT(fixture->vtable->check_handshaker_peers != nullptr);
-  /* Check handshaker peers. */
+  // Check handshaker peers.
   fixture->vtable->check_handshaker_peers(fixture);
-  /* Check unused bytes. */
+  // Check unused bytes.
   if (fixture->test_unused_bytes) {
     tsi_test_channel* channel = fixture->channel;
     if (fixture->server_result != nullptr &&
@@ -135,7 +136,7 @@ static void send_bytes_to_peer(tsi_test_channel* test_channel,
                               : &test_channel->bytes_written_to_client_channel;
   GPR_ASSERT(bytes_written != nullptr);
   GPR_ASSERT(*bytes_written + buf_size <= TSI_TEST_DEFAULT_CHANNEL_SIZE);
-  /* Write data to channel. */
+  // Write data to channel.
   memcpy(channel + *bytes_written, buf, buf_size);
   *bytes_written += buf_size;
 }
@@ -177,7 +178,7 @@ static void receive_bytes_from_peer(tsi_test_channel* test_channel,
   size_t to_read = *buf_size < *bytes_written - *bytes_read
                        ? *buf_size
                        : *bytes_written - *bytes_read;
-  /* Read data from channel. */
+  // Read data from channel.
   memcpy(*buf, channel + *bytes_read, to_read);
   *buf_size = to_read;
   *bytes_read += to_read;
@@ -186,7 +187,7 @@ static void receive_bytes_from_peer(tsi_test_channel* test_channel,
 void tsi_test_frame_protector_send_message_to_peer(
     tsi_test_frame_protector_config* config, tsi_test_channel* channel,
     tsi_frame_protector* protector, bool is_client) {
-  /* Initialization. */
+  // Initialization.
   GPR_ASSERT(config != nullptr);
   GPR_ASSERT(channel != nullptr);
   GPR_ASSERT(protector != nullptr);
@@ -200,21 +201,21 @@ void tsi_test_frame_protector_send_message_to_peer(
   const unsigned char* message_bytes =
       reinterpret_cast<unsigned char*>(message);
   tsi_result result = TSI_OK;
-  /* Do protect and send protected data to peer. */
+  // Do protect and send protected data to peer.
   while (message_size > 0 && result == TSI_OK) {
     size_t protected_buffer_size_to_send = config->protected_buffer_size;
     size_t processed_message_size = message_size;
-    /* Do protect. */
+    // Do protect.
     result = tsi_frame_protector_protect(
         protector, message_bytes, &processed_message_size, protected_buffer,
         &protected_buffer_size_to_send);
     GPR_ASSERT(result == TSI_OK);
-    /* Send protected data to peer. */
+    // Send protected data to peer.
     send_bytes_to_peer(channel, protected_buffer, protected_buffer_size_to_send,
                        is_client);
     message_bytes += processed_message_size;
     message_size -= processed_message_size;
-    /* Flush if we're done. */
+    // Flush if we're done.
     if (message_size == 0) {
       size_t still_pending_size;
       do {
@@ -237,7 +238,7 @@ void tsi_test_frame_protector_receive_message_from_peer(
     tsi_test_frame_protector_config* config, tsi_test_channel* channel,
     tsi_frame_protector* protector, unsigned char* message,
     size_t* bytes_received, bool is_client) {
-  /* Initialization. */
+  // Initialization.
   GPR_ASSERT(config != nullptr);
   GPR_ASSERT(channel != nullptr);
   GPR_ASSERT(protector != nullptr);
@@ -252,9 +253,9 @@ void tsi_test_frame_protector_receive_message_from_peer(
       gpr_zalloc(config->read_buffer_allocated_size));
   unsigned char* message_buffer = static_cast<unsigned char*>(
       gpr_zalloc(config->message_buffer_allocated_size));
-  /* Do unprotect on data received from peer. */
+  // Do unprotect on data received from peer.
   while (!done && result == TSI_OK) {
-    /* Receive data from peer. */
+    // Receive data from peer.
     if (read_from_peer_size == 0) {
       read_from_peer_size = config->read_buffer_allocated_size;
       receive_bytes_from_peer(channel, &read_buffer, &read_from_peer_size,
@@ -264,7 +265,7 @@ void tsi_test_frame_protector_receive_message_from_peer(
     if (read_from_peer_size == 0) {
       done = true;
     }
-    /* Do unprotect. */
+    // Do unprotect.
     size_t message_buffer_size;
     do {
       message_buffer_size = config->message_buffer_allocated_size;
@@ -297,7 +298,7 @@ grpc_error_handle on_handshake_next_done(
   GPR_ASSERT(args->fixture != nullptr);
   tsi_test_fixture* fixture = args->fixture;
   grpc_error_handle error;
-  /* Read more data if we need to. */
+  // Read more data if we need to.
   if (result == TSI_INCOMPLETE_DATA) {
     GPR_ASSERT(bytes_to_send_size == 0);
     notification_signal(fixture);
@@ -308,14 +309,14 @@ grpc_error_handle on_handshake_next_done(
     return grpc_set_tsi_error_result(GRPC_ERROR_CREATE("Handshake failed"),
                                      result);
   }
-  /* Update handshaker result. */
+  // Update handshaker result.
   if (handshaker_result != nullptr) {
     tsi_handshaker_result** result_to_write =
         args->is_client ? &fixture->client_result : &fixture->server_result;
     GPR_ASSERT(*result_to_write == nullptr);
     *result_to_write = handshaker_result;
   }
-  /* Send data to peer, if needed. */
+  // Send data to peer, if needed.
   if (bytes_to_send_size > 0) {
     send_bytes_to_peer(fixture->channel, bytes_to_send, bytes_to_send_size,
                        args->is_client);
@@ -345,7 +346,7 @@ static bool is_handshake_finished_properly(handshaker_args* args) {
 }
 
 static void do_handshaker_next(handshaker_args* args) {
-  /* Initialization. */
+  // Initialization.
   GPR_ASSERT(args != nullptr);
   GPR_ASSERT(args->fixture != nullptr);
   tsi_test_fixture* fixture = args->fixture;
@@ -358,7 +359,7 @@ static void do_handshaker_next(handshaker_args* args) {
   unsigned char* bytes_to_send = nullptr;
   size_t bytes_to_send_size = 0;
   tsi_result result = TSI_OK;
-  /* Receive data from peer, if available. */
+  // Receive data from peer, if available.
   do {
     size_t buf_size = args->handshake_buffer_size;
     receive_bytes_from_peer(fixture->channel, &args->handshake_buffer,
@@ -366,7 +367,7 @@ static void do_handshaker_next(handshaker_args* args) {
     if (buf_size > 0) {
       args->transferred_data = true;
     }
-    /* Peform handshaker next. */
+    // Peform handshaker next.
     result = tsi_handshaker_next(
         handshaker, args->handshake_buffer, buf_size,
         const_cast<const unsigned char**>(&bytes_to_send), &bytes_to_send_size,
@@ -383,13 +384,13 @@ static void do_handshaker_next(handshaker_args* args) {
 }
 
 void tsi_test_do_handshake(tsi_test_fixture* fixture) {
-  /* Initializaiton. */
+  // Initializaiton.
   setup_handshakers(fixture);
   handshaker_args* client_args =
       handshaker_args_create(fixture, true /* is_client */);
   handshaker_args* server_args =
       handshaker_args_create(fixture, false /* is_client */);
-  /* Do handshake. */
+  // Do handshake.
   do {
     client_args->transferred_data = false;
     server_args->transferred_data = false;
@@ -404,9 +405,9 @@ void tsi_test_do_handshake(tsi_test_fixture* fixture) {
     GPR_ASSERT(client_args->transferred_data || server_args->transferred_data);
   } while (fixture->client_result == nullptr ||
            fixture->server_result == nullptr);
-  /* Verify handshake results. */
+  // Verify handshake results.
   check_handshake_results(fixture);
-  /* Cleanup. */
+  // Cleanup.
   handshaker_args_destroy(client_args);
   handshaker_args_destroy(server_args);
 }
@@ -419,7 +420,7 @@ static void tsi_test_do_ping_pong(tsi_test_frame_protector_config* config,
   GPR_ASSERT(channel != nullptr);
   GPR_ASSERT(client_frame_protector != nullptr);
   GPR_ASSERT(server_frame_protector != nullptr);
-  /* Client sends a message to server. */
+  // Client sends a message to server.
   tsi_test_frame_protector_send_message_to_peer(
       config, channel, client_frame_protector, true /* is_client */);
   unsigned char* server_received_message =
@@ -431,7 +432,7 @@ static void tsi_test_do_ping_pong(tsi_test_frame_protector_config* config,
   GPR_ASSERT(config->client_message_size == server_received_message_size);
   GPR_ASSERT(memcmp(config->client_message, server_received_message,
                     server_received_message_size) == 0);
-  /* Server sends a message to client. */
+  // Server sends a message to client.
   tsi_test_frame_protector_send_message_to_peer(
       config, channel, server_frame_protector, false /* is_client */);
   unsigned char* client_received_message =
@@ -456,15 +457,15 @@ void tsi_test_frame_protector_do_round_trip_no_handshake(
 }
 
 void tsi_test_do_round_trip(tsi_test_fixture* fixture) {
-  /* Initialization. */
+  // Initialization.
   GPR_ASSERT(fixture != nullptr);
   GPR_ASSERT(fixture->config != nullptr);
   tsi_test_frame_protector_config* config = fixture->config;
   tsi_frame_protector* client_frame_protector = nullptr;
   tsi_frame_protector* server_frame_protector = nullptr;
-  /* Perform handshake. */
+  // Perform handshake.
   tsi_test_do_handshake(fixture);
-  /* Create frame protectors.*/
+  // Create frame protectors.
   size_t client_max_output_protected_frame_size =
       config->client_max_output_protected_frame_size;
   GPR_ASSERT(tsi_handshaker_result_create_frame_protector(
@@ -483,7 +484,7 @@ void tsi_test_do_round_trip(tsi_test_fixture* fixture) {
                  &server_frame_protector) == TSI_OK);
   tsi_test_do_ping_pong(config, fixture->channel, client_frame_protector,
                         server_frame_protector);
-  /* Destroy server and client frame protectors. */
+  // Destroy server and client frame protectors.
   tsi_frame_protector_destroy(client_frame_protector);
   tsi_frame_protector_destroy(server_frame_protector);
 }
@@ -509,21 +510,21 @@ tsi_test_frame_protector_config* tsi_test_frame_protector_config_create(
   tsi_test_frame_protector_config* config =
       static_cast<tsi_test_frame_protector_config*>(
           gpr_zalloc(sizeof(*config)));
-  /* Set the value for read_buffer_allocated_size. */
+  // Set the value for read_buffer_allocated_size.
   config->read_buffer_allocated_size =
       use_default_read_buffer_allocated_size
           ? TSI_TEST_DEFAULT_BUFFER_SIZE
           : TSI_TEST_SMALL_READ_BUFFER_ALLOCATED_SIZE;
-  /* Set the value for message_buffer_allocated_size. */
+  // Set the value for message_buffer_allocated_size.
   config->message_buffer_allocated_size =
       use_default_message_buffer_allocated_size
           ? TSI_TEST_DEFAULT_BUFFER_SIZE
           : TSI_TEST_SMALL_MESSAGE_BUFFER_ALLOCATED_SIZE;
-  /* Set the value for protected_buffer_size. */
+  // Set the value for protected_buffer_size.
   config->protected_buffer_size = use_default_protected_buffer_size
                                       ? TSI_TEST_DEFAULT_PROTECTED_BUFFER_SIZE
                                       : TSI_TEST_SMALL_PROTECTED_BUFFER_SIZE;
-  /* Set the value for client message. */
+  // Set the value for client message.
   config->client_message_size = use_default_client_message
                                     ? TSI_TEST_BIG_MESSAGE_SIZE
                                     : TSI_TEST_SMALL_MESSAGE_SIZE;
@@ -531,7 +532,7 @@ tsi_test_frame_protector_config* tsi_test_frame_protector_config_create(
       use_default_client_message
           ? generate_random_message(TSI_TEST_BIG_MESSAGE_SIZE)
           : generate_random_message(TSI_TEST_SMALL_MESSAGE_SIZE);
-  /* Set the value for server message. */
+  // Set the value for server message.
   config->server_message_size = use_default_server_message
                                     ? TSI_TEST_BIG_MESSAGE_SIZE
                                     : TSI_TEST_SMALL_MESSAGE_SIZE;
@@ -539,16 +540,16 @@ tsi_test_frame_protector_config* tsi_test_frame_protector_config_create(
       use_default_server_message
           ? generate_random_message(TSI_TEST_BIG_MESSAGE_SIZE)
           : generate_random_message(TSI_TEST_SMALL_MESSAGE_SIZE);
-  /* Set the value for client max_output_protected_frame_size.
-     If it is 0, we pass NULL to tsi_handshaker_result_create_frame_protector(),
-     which then uses default protected frame size for it. */
+  // Set the value for client max_output_protected_frame_size.
+  // If it is 0, we pass NULL to tsi_handshaker_result_create_frame_protector(),
+  // which then uses default protected frame size for it.
   config->client_max_output_protected_frame_size =
       use_default_client_max_output_protected_frame_size
           ? 0
           : TSI_TEST_SMALL_CLIENT_MAX_OUTPUT_PROTECTED_FRAME_SIZE;
-  /* Set the value for server max_output_protected_frame_size.
-     If it is 0, we pass NULL to tsi_handshaker_result_create_frame_protector(),
-     which then uses default protected frame size for it. */
+  // Set the value for server max_output_protected_frame_size.
+  // If it is 0, we pass NULL to tsi_handshaker_result_create_frame_protector(),
+  // which then uses default protected frame size for it.
   config->server_max_output_protected_frame_size =
       use_default_server_max_output_protected_frame_size
           ? 0
