@@ -19,8 +19,9 @@
 #include <stdbool.h>
 
 #include <grpc/grpc.h>
-
 #include <grpc/support/log.h>
+
+#include "src/core/lib/gprpp/crash.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
 #include "src/core/lib/iomgr/load_file.h"
 
@@ -36,6 +37,7 @@ int main(int argc, char** argv) {
   /* TODO(yashkt) Calling grpc_init breaks tests. Fix the tests and replace
    * grpc_core::ExecCtx::GlobalInit with grpc_init and GlobalShutdown with
    * grpc_shutdown */
+  GPR_ASSERT(argc > 1); /* Make sure that we have a filename argument */
   GPR_ASSERT(
       GRPC_LOG_IF_ERROR("load_file", grpc_load_file(argv[1], 0, &buffer)));
   LLVMFuzzerTestOneInput(GRPC_SLICE_START_PTR(buffer),
