@@ -1,20 +1,20 @@
-/*
- *
- * Copyright 2016 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2016 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #include "test/core/util/passthru_endpoint.h"
 
@@ -207,7 +207,7 @@ static void do_pending_write_op_locked(half* m, grpc_error_handle error) {
       other->on_read != nullptr ? other->on_read_out : &other->read_buffer;
   while (max_writable > 0) {
     grpc_slice slice = grpc_slice_buffer_take_first(slices);
-    uint64_t slice_length = GPR_SLICE_LENGTH(slice);
+    uint64_t slice_length = GRPC_SLICE_LENGTH(slice);
     GPR_ASSERT(slice_length > 0);
     grpc_slice split1, split2;
     uint64_t split_length = 0;
@@ -230,7 +230,7 @@ static void do_pending_write_op_locked(half* m, grpc_error_handle error) {
     // Write a copy of the slice to the destination to be read
     grpc_slice_buffer_add_indexed(dest, split1);
     // Re-insert split2 into source for next iteration.
-    if (GPR_SLICE_LENGTH(split2) > 0) {
+    if (GRPC_SLICE_LENGTH(split2) > 0) {
       grpc_slice_buffer_undo_take_first(slices, split2);
     } else {
       grpc_slice_unref(split2);
@@ -277,7 +277,7 @@ static void me_write(grpc_endpoint* ep, grpc_slice_buffer* slices,
     m->pending_write_op.slices = &m->write_buffer;
     GPR_ASSERT(m->pending_write_op.slices->count == 0);
     for (int i = 0; i < static_cast<int>(slices->count); i++) {
-      if (GPR_SLICE_LENGTH(slices->slices[i]) > 0) {
+      if (GRPC_SLICE_LENGTH(slices->slices[i]) > 0) {
         grpc_slice_buffer_add_indexed(m->pending_write_op.slices,
                                       grpc_slice_copy(slices->slices[i]));
       }
