@@ -27,6 +27,7 @@
 #include "absl/status/status.h"
 #include "absl/status/statusor.h"
 #include "absl/strings/str_cat.h"
+#include "absl/strings/str_format.h"
 #include "absl/strings/string_view.h"
 #include "absl/types/optional.h"
 #include "absl/types/variant.h"
@@ -36,7 +37,6 @@
 #include "upb/upb.hpp"
 
 #include <grpc/grpc.h>
-#include <grpc/support/log.h>
 
 #include "src/core/ext/xds/xds_bootstrap.h"
 #include "src/core/ext/xds/xds_bootstrap_grpc.h"
@@ -46,6 +46,7 @@
 #include "src/core/ext/xds/xds_resource_type.h"
 #include "src/core/lib/address_utils/sockaddr_utils.h"
 #include "src/core/lib/debug/trace.h"
+#include "src/core/lib/gprpp/crash.h"
 #include "src/core/lib/gprpp/ref_counted_ptr.h"
 #include "src/core/lib/gprpp/time.h"
 #include "src/core/lib/iomgr/error.h"
@@ -110,12 +111,13 @@ class XdsListenerTest : public ::testing::Test {
         "  }\n"
         "}");
     if (!bootstrap.ok()) {
-      gpr_log(GPR_ERROR, "Error parsing bootstrap: %s",
-              bootstrap.status().ToString().c_str());
-      GPR_ASSERT(false);
+      Crash(absl::StrFormat("Error parsing bootstrap: %s",
+                            bootstrap.status().ToString().c_str()));
     }
     return MakeRefCounted<XdsClient>(std::move(*bootstrap),
-                                     /*transport_factory=*/nullptr);
+                                     /*transport_factory=*/nullptr,
+                                     /*event_engine=*/nullptr, "foo agent",
+                                     "foo version");
   }
 
   RefCountedPtr<XdsClient> xds_client_;
@@ -578,37 +580,6 @@ TEST_P(HttpConnectionManagerTest, HttpFilterMissingConfig) {
       << decode_result.resource.status();
 }
 
-TEST_P(HttpConnectionManagerTest, HttpFilterMissingConfigButOptional) {
-  HttpConnectionManager hcm;
-  auto* filter = hcm.add_http_filters();
-  filter->set_name("foo");
-  filter->set_is_optional(true);
-  filter = hcm.add_http_filters();
-  filter->set_name("router");
-  filter->mutable_typed_config()->PackFrom(Router());
-  auto* rds = hcm.mutable_rds();
-  rds->set_route_config_name("rds_name");
-  rds->mutable_config_source()->mutable_self();
-  Listener listener = MakeListener(hcm);
-  std::string serialized_resource;
-  ASSERT_TRUE(listener.SerializeToString(&serialized_resource));
-  auto* resource_type = XdsListenerResourceType::Get();
-  auto decode_result =
-      resource_type->Decode(decode_context_, serialized_resource);
-  ASSERT_TRUE(decode_result.resource.ok()) << decode_result.resource.status();
-  ASSERT_TRUE(decode_result.name.has_value());
-  EXPECT_EQ(*decode_result.name, "foo");
-  auto& resource = static_cast<XdsListenerResource&>(**decode_result.resource);
-  auto http_connection_manager = GetHCMConfig(resource);
-  ASSERT_TRUE(http_connection_manager.has_value());
-  ASSERT_EQ(http_connection_manager->http_filters.size(), 1UL);
-  auto& router = http_connection_manager->http_filters[0];
-  EXPECT_EQ(router.name, "router");
-  EXPECT_EQ(router.config.config_proto_type_name,
-            "envoy.extensions.filters.http.router.v3.Router");
-  EXPECT_EQ(router.config.config, Json()) << router.config.config.Dump();
-}
-
 TEST_P(HttpConnectionManagerTest, HttpFilterTypeNotSupported) {
   HttpConnectionManager hcm;
   auto* filter = hcm.add_http_filters();
