@@ -1,20 +1,20 @@
-/*
- *
- * Copyright 2018 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2018 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #include <string>
 #include <thread>  // NOLINT
@@ -35,11 +35,14 @@
 #include <grpcpp/opencensus.h>
 
 #include "src/core/lib/channel/call_tracer.h"
+#include "src/core/lib/config/core_configuration.h"
+#include "src/core/lib/load_balancing/lb_policy.h"
 #include "src/cpp/ext/filters/census/context.h"
 #include "src/cpp/ext/filters/census/grpc_plugin.h"
 #include "src/cpp/ext/filters/census/open_census_call_tracer.h"
 #include "src/proto/grpc/testing/echo.grpc.pb.h"
 #include "test/core/util/test_config.h"
+#include "test/core/util/test_lb_policies.h"
 #include "test/cpp/end2end/test_service_impl.h"
 
 namespace opencensus {
@@ -143,7 +146,12 @@ class ExportedTracesRecorder
 
 class StatsPluginEnd2EndTest : public ::testing::Test {
  protected:
-  static void SetUpTestCase() {
+  static void SetUpTestSuite() {
+    grpc_core::CoreConfiguration::Reset();
+    grpc_core::CoreConfiguration::RegisterBuilder(
+        [](grpc_core::CoreConfiguration::Builder* builder) {
+          grpc_core::RegisterQueueOnceLoadBalancingPolicy(builder);
+        });
     RegisterOpenCensusPlugin();
     // OpenCensus C++ has no API to unregister a previously-registered handler,
     // therefore we register this handler once, and enable/disable recording in
@@ -152,6 +160,11 @@ class StatsPluginEnd2EndTest : public ::testing::Test {
         absl::WrapUnique(traces_recorder_));
   }
 
+  static void TearDownTestSuite() {
+    grpc_shutdown();
+    grpc_core::CoreConfiguration::Reset();
+  }
+
   void SetUp() override {
     // Set up a synchronous server on a different thread to avoid the asynch
     // interface.
@@ -685,6 +698,15 @@ TEST_F(StatsPluginEnd2EndTest, TestApplicationCensusContextFlows) {
   EXPECT_TRUE(status.ok());
 }
 
+std::vector<opencensus::trace::exporter::SpanData>::const_iterator
+GetSpanByName(
+    const std::vector<::opencensus::trace::exporter::SpanData>& recorded_spans,
+    absl::string_view name) {
+  return std::find_if(
+      recorded_spans.begin(), recorded_spans.end(),
+      [name](auto const& span_data) { return span_data.name() == name; });
+}
+
 TEST_F(StatsPluginEnd2EndTest, TestAllSpansAreExported) {
   {
     // Client spans are ended when the ClientContext's destructor is invoked.
@@ -715,29 +737,88 @@ TEST_F(StatsPluginEnd2EndTest, TestAllSpansAreExported) {
   ::opencensus::trace::exporter::SpanExporterTestPeer::ExportForTesting();
   traces_recorder_->StopRecording();
   auto recorded_spans = traces_recorder_->GetAndClearSpans();
-  auto GetSpanByName = [&recorded_spans](absl::string_view name) {
-    return std::find_if(
-        recorded_spans.begin(), recorded_spans.end(),
-        [name](auto const& span_data) { return span_data.name() == name; });
-  };
   // We never ended the two spans created in the scope above, so we don't
   // expect them to be exported.
   ASSERT_EQ(3, recorded_spans.size());
   auto sent_span_data =
-      GetSpanByName(absl::StrCat("Sent.", client_method_name_));
+      GetSpanByName(recorded_spans, absl::StrCat("Sent.", client_method_name_));
   ASSERT_NE(sent_span_data, recorded_spans.end());
-  auto attempt_span_data =
-      GetSpanByName(absl::StrCat("Attempt.", client_method_name_));
+  auto attempt_span_data = GetSpanByName(
+      recorded_spans, absl::StrCat("Attempt.", client_method_name_));
   ASSERT_NE(attempt_span_data, recorded_spans.end());
   EXPECT_EQ(sent_span_data->context().span_id(),
             attempt_span_data->parent_span_id());
   auto recv_span_data =
-      GetSpanByName(absl::StrCat("Recv.", server_method_name_));
+      GetSpanByName(recorded_spans, absl::StrCat("Recv.", server_method_name_));
   ASSERT_NE(recv_span_data, recorded_spans.end());
   EXPECT_EQ(attempt_span_data->context().span_id(),
             recv_span_data->parent_span_id());
 }
 
+bool IsAnnotationPresent(
+    std::vector<opencensus::trace::exporter::SpanData>::const_iterator span,
+    absl::string_view annotation) {
+  for (const auto& event : span->annotations().events()) {
+    if (event.event().description() == annotation) {
+      return true;
+    }
+  }
+  return false;
+}
+
+// Tests that the trace annotations for when a call is removed from pending
+// resolver result queue, and for when a call is removed from pending lb pick
+// queue, are recorded.
+TEST_F(StatsPluginEnd2EndTest,
+       TestRemovePendingResolverResultAndPendingLbPickQueueAnnotations) {
+  {
+    // Client spans are ended when the ClientContext's destructor is invoked.
+    ChannelArguments args;
+    args.SetLoadBalancingPolicyName("queue_once");
+    auto channel = CreateCustomChannel(server_address_,
+                                       InsecureChannelCredentials(), args);
+    ResetStub(channel);
+    EchoRequest request;
+    request.set_message("foo");
+    EchoResponse response;
+
+    grpc::ClientContext context;
+    ::opencensus::trace::AlwaysSampler always_sampler;
+    ::opencensus::trace::StartSpanOptions options;
+    options.sampler = &always_sampler;
+    auto sampling_span =
+        ::opencensus::trace::Span::StartSpan("sampling", nullptr, options);
+    grpc::CensusContext app_census_context("root", &sampling_span,
+                                           ::opencensus::tags::TagMap{});
+    context.set_census_context(
+        reinterpret_cast<census_context*>(&app_census_context));
+    context.AddMetadata(kExpectedTraceIdKey,
+                        app_census_context.Span().context().trace_id().ToHex());
+    traces_recorder_->StartRecording();
+    grpc::Status status = stub_->Echo(&context, request, &response);
+    EXPECT_TRUE(status.ok());
+  }
+  absl::SleepFor(absl::Milliseconds(500 * grpc_test_slowdown_factor()));
+  TestUtils::Flush();
+  ::opencensus::trace::exporter::SpanExporterTestPeer::ExportForTesting();
+  traces_recorder_->StopRecording();
+  auto recorded_spans = traces_recorder_->GetAndClearSpans();
+  // Check presence of trace annotation for removal from channel's pending
+  // resolver result queue.
+  auto sent_span_data =
+      GetSpanByName(recorded_spans, absl::StrCat("Sent.", client_method_name_));
+  ASSERT_NE(sent_span_data, recorded_spans.end());
+  EXPECT_TRUE(
+      IsAnnotationPresent(sent_span_data, "Delayed name resolution complete."));
+  // Check presence of trace annotation for removal from channel's pending
+  // lb pick queue.
+  auto attempt_span_data = GetSpanByName(
+      recorded_spans, absl::StrCat("Attempt.", client_method_name_));
+  ASSERT_NE(attempt_span_data, recorded_spans.end());
+  EXPECT_TRUE(
+      IsAnnotationPresent(attempt_span_data, "Delayed LB pick complete."));
+}
+
 // Test the working of GRPC_ARG_DISABLE_OBSERVABILITY.
 TEST_F(StatsPluginEnd2EndTest, TestObservabilityDisabledChannelArg) {
   {
@@ -770,21 +851,15 @@ TEST_F(StatsPluginEnd2EndTest, TestObservabilityDisabledChannelArg) {
   ::opencensus::trace::exporter::SpanExporterTestPeer::ExportForTesting();
   traces_recorder_->StopRecording();
   auto recorded_spans = traces_recorder_->GetAndClearSpans();
-  auto GetSpanByName = [&recorded_spans](absl::string_view name) {
-    return std::find_if(
-        recorded_spans.begin(), recorded_spans.end(),
-        [name](auto const& span_data) { return span_data.name() == name; });
-  };
-
   // The size might be 0 or 1, depending on whether the server-side ends up
   // getting sampled or not.
   ASSERT_LE(recorded_spans.size(), 1);
   // Make sure that the client-side traces are not collected.
   auto sent_span_data =
-      GetSpanByName(absl::StrCat("Sent.", client_method_name_));
+      GetSpanByName(recorded_spans, absl::StrCat("Sent.", client_method_name_));
   ASSERT_EQ(sent_span_data, recorded_spans.end());
-  auto attempt_span_data =
-      GetSpanByName(absl::StrCat("Attempt.", client_method_name_));
+  auto attempt_span_data = GetSpanByName(
+      recorded_spans, absl::StrCat("Attempt.", client_method_name_));
   ASSERT_EQ(attempt_span_data, recorded_spans.end());
 }
 
