@@ -1,20 +1,20 @@
-/*
- *
- * Copyright 2015-2016 gRPC authors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- */
+//
+//
+// Copyright 2015-2016 gRPC authors.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+//
+//
 
 #include "test/cpp/interop/interop_client.h"
 
@@ -37,6 +37,7 @@
 #include <grpcpp/client_context.h>
 #include <grpcpp/security/credentials.h>
 
+#include "src/core/lib/gprpp/crash.h"
 #include "src/proto/grpc/testing/empty.pb.h"
 #include "src/proto/grpc/testing/messages.pb.h"
 #include "src/proto/grpc/testing/test.grpc.pb.h"
@@ -68,10 +69,9 @@ void UnaryCompressionChecks(const InteropClientContextInspector& inspector,
   if (request->response_compressed().value()) {
     if (received_compression == GRPC_COMPRESS_NONE) {
       // Requested some compression, got NONE. This is an error.
-      gpr_log(GPR_ERROR,
-              "Failure: Requested compression but got uncompressed response "
-              "from server.");
-      abort();
+      grpc_core::Crash(
+          "Failure: Requested compression but got uncompressed response "
+          "from server.");
     }
     GPR_ASSERT(inspector.WasCompressed());
   } else {
@@ -224,7 +224,7 @@ bool InteropClient::DoComputeEngineCreds(
   gpr_log(GPR_DEBUG, "Got username %s", response.username().c_str());
   gpr_log(GPR_DEBUG, "Got oauth_scope %s", response.oauth_scope().c_str());
   GPR_ASSERT(!response.username().empty());
-  GPR_ASSERT(response.username().c_str() == default_service_account);
+  GPR_ASSERT(response.username() == default_service_account);
   GPR_ASSERT(!response.oauth_scope().empty());
   const char* oauth_scope_str = response.oauth_scope().c_str();
   GPR_ASSERT(absl::StrContains(oauth_scope, oauth_scope_str));
@@ -314,7 +314,7 @@ bool InteropClient::DoGoogleDefaultCredentials(
 
   gpr_log(GPR_DEBUG, "Got username %s", response.username().c_str());
   GPR_ASSERT(!response.username().empty());
-  GPR_ASSERT(response.username().c_str() == default_service_account);
+  GPR_ASSERT(response.username() == default_service_account);
   gpr_log(GPR_DEBUG, "Large unary rpc with GoogleDefaultCredentials done.");
   return true;
 }
@@ -1056,8 +1056,8 @@ InteropClient::PerformOneSoakTestIteration(
 }
 
 void InteropClient::PerformSoakTest(
-    const bool reset_channel_per_iteration, const int32_t soak_iterations,
-    const int32_t max_failures,
+    const std::string& server_uri, const bool reset_channel_per_iteration,
+    const int32_t soak_iterations, const int32_t max_failures,
     const int32_t max_acceptable_per_iteration_latency_ms,
     const int32_t min_time_ms_between_rpcs,
     const int32_t overall_timeout_seconds) {
@@ -1086,12 +1086,16 @@ void InteropClient::PerformSoakTest(
     results.push_back(result);
     if (!success) {
       gpr_log(GPR_DEBUG,
-              "soak iteration: %d elapsed_ms: %d peer: %s failed: %s", i,
-              elapsed_ms, peer.c_str(), debug_string.c_str());
+              "soak iteration: %d elapsed_ms: %d peer: %s server_uri: %s "
+              "failed: %s",
+              i, elapsed_ms, peer.c_str(), server_uri.c_str(),
+              debug_string.c_str());
       total_failures++;
     } else {
-      gpr_log(GPR_DEBUG, "soak iteration: %d elapsed_ms: %d peer: %s succeeded",
-              i, elapsed_ms, peer.c_str());
+      gpr_log(
+          GPR_DEBUG,
+          "soak iteration: %d elapsed_ms: %d peer: %s server_uri: %s succeeded",
+          i, elapsed_ms, peer.c_str(), server_uri.c_str());
     }
     grpc_histogram_add(latencies_ms_histogram, std::get<1>(result));
     iterations_ran++;
@@ -1106,7 +1110,8 @@ void InteropClient::PerformSoakTest(
   if (iterations_ran < soak_iterations) {
     gpr_log(
         GPR_ERROR,
-        "soak test consumed all %d seconds of time and quit early, only "
+        "(server_uri: %s) soak test consumed all %d seconds of time and quit "
+        "early, only "
         "having ran %d out of desired %d iterations. "
         "total_failures: %d. "
         "max_failures_threshold: %d. "
@@ -1116,58 +1121,62 @@ void InteropClient::PerformSoakTest(
         "Some or all of the iterations that did run were unexpectedly slow. "
         "See breakdown above for which iterations succeeded, failed, and "
         "why for more info.",
-        overall_timeout_seconds, iterations_ran, soak_iterations,
-        total_failures, max_failures, latency_ms_median, latency_ms_90th,
-        latency_ms_worst);
+        server_uri.c_str(), overall_timeout_seconds, iterations_ran,
+        soak_iterations, total_failures, max_failures, latency_ms_median,
+        latency_ms_90th, latency_ms_worst);
     GPR_ASSERT(0);
   } else if (total_failures > max_failures) {
     gpr_log(GPR_ERROR,
-            "soak test ran: %d iterations. total_failures: %d exceeds "
+            "(server_uri: %s) soak test ran: %d iterations. total_failures: %d "
+            "exceeds "
             "max_failures_threshold: %d. "
             "median_soak_iteration_latency: %lf ms. "
             "90th_soak_iteration_latency: %lf ms. "
             "worst_soak_iteration_latency: %lf ms. "
             "See breakdown above for which iterations succeeded, failed, and "
             "why for more info.",
-            soak_iterations, total_failures, max_failures, latency_ms_median,
-            latency_ms_90th, latency_ms_worst);
+            server_uri.c_str(), soak_iterations, total_failures, max_failures,
+            latency_ms_median, latency_ms_90th, latency_ms_worst);
     GPR_ASSERT(0);
   } else {
     gpr_log(GPR_INFO,
-            "soak test ran: %d iterations. total_failures: %d is within "
+            "(server_uri: %s) soak test ran: %d iterations. total_failures: %d "
+            "is within "
             "max_failures_threshold: %d. "
             "median_soak_iteration_latency: %lf ms. "
             "90th_soak_iteration_latency: %lf ms. "
             "worst_soak_iteration_latency: %lf ms. "
             "See breakdown above for which iterations succeeded, failed, and "
             "why for more info.",
-            soak_iterations, total_failures, max_failures, latency_ms_median,
-            latency_ms_90th, latency_ms_worst);
+            server_uri.c_str(), soak_iterations, total_failures, max_failures,
+            latency_ms_median, latency_ms_90th, latency_ms_worst);
   }
 }
 
 bool InteropClient::DoRpcSoakTest(
-    int32_t soak_iterations, int32_t max_failures,
-    int64_t max_acceptable_per_iteration_latency_ms,
+    const std::string& server_uri, int32_t soak_iterations,
+    int32_t max_failures, int64_t max_acceptable_per_iteration_latency_ms,
     int32_t soak_min_time_ms_between_rpcs, int32_t overall_timeout_seconds) {
   gpr_log(GPR_DEBUG, "Sending %d RPCs...", soak_iterations);
   GPR_ASSERT(soak_iterations > 0);
-  PerformSoakTest(false /* reset channel per iteration */, soak_iterations,
-                  max_failures, max_acceptable_per_iteration_latency_ms,
+  PerformSoakTest(server_uri, false /* reset channel per iteration */,
+                  soak_iterations, max_failures,
+                  max_acceptable_per_iteration_latency_ms,
                   soak_min_time_ms_between_rpcs, overall_timeout_seconds);
   gpr_log(GPR_DEBUG, "rpc_soak test done.");
   return true;
 }
 
 bool InteropClient::DoChannelSoakTest(
-    int32_t soak_iterations, int32_t max_failures,
-    int64_t max_acceptable_per_iteration_latency_ms,
+    const std::string& server_uri, int32_t soak_iterations,
+    int32_t max_failures, int64_t max_acceptable_per_iteration_latency_ms,
     int32_t soak_min_time_ms_between_rpcs, int32_t overall_timeout_seconds) {
   gpr_log(GPR_DEBUG, "Sending %d RPCs, tearing down the channel each time...",
           soak_iterations);
   GPR_ASSERT(soak_iterations > 0);
-  PerformSoakTest(true /* reset channel per iteration */, soak_iterations,
-                  max_failures, max_acceptable_per_iteration_latency_ms,
+  PerformSoakTest(server_uri, true /* reset channel per iteration */,
+                  soak_iterations, max_failures,
+                  max_acceptable_per_iteration_latency_ms,
                   soak_min_time_ms_between_rpcs, overall_timeout_seconds);
   gpr_log(GPR_DEBUG, "channel_soak test done.");
   return true;
